@@ -20,11 +20,25 @@
 /*     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.         */
 /* --------------------------------------------------------------------  */
 
-/* ALL function prototypes for the program "CalculiX GraphiX (cgx)" */
+#define     VERSION         "2.21"
+
+/* function prototypes for the program "CalculiX GraphiX (cgx)" */
 
 #include "extUtil.h"
 #include "trackball.h"
 
+/* change from sem_open to sem_init */
+#ifdef SEMINIT
+#else
+#define sem_n *nptr
+#define sem_g *gptr
+#define sem_rep *rptr
+#define sem_stn *sptr
+#define sem_nurs *nuptr
+#define sem_map3d *mptr
+#define sem_cute *cptr
+#endif    
+
 
 /* factors for the geometric tolerance for merging */
 /* the space used by all lines will be multiplied with this value to calculate the default */
@@ -73,23 +87,23 @@
 /* default location of the help files, please insert the actual one */
 #ifdef MTU
   #ifdef DEVEL
-    #define     HELPFILE        {"/yaprod/struct/SLE12/app/cgx/prod/doc/cgx.html",\
-                             "/yaprod/struct/SLE12/app/ccx/prod/doc/ccx.html"}
+    #define     HELPFILE        {"/yaprod/struct/app/cgx/prod/doc/cgx.html",\
+                             "/yaprod/struct/app/ccx/prod/doc/ccx.html"}
   #else
-    #define     HELPFILE        {"/yaprod/cae/application/CalculiX/doc/cgx_2.17/cgx.html",\
-                             "/yaprod/cae/application/CalculiX/doc/ccx_2.17/ccx.html"}
+    #define     HELPFILE        {"/yaprod/cae/application/CalculiX/doc/cgx_2.21/cgx.html",\
+                             "/yaprod/cae/application/CalculiX/doc/ccx_2.21/ccx.html"}
   #endif
   /* default tet mesher, 0:Netgen ng_vol, 1:tetgen */
   #define     TETMESHER  0
 #elif defined AFLIB
-  #define     HELPFILE        {"/usr/local/CalculiX/cgx_2.17/doc/cgx/cgx.html",\
-    "/usr/local/CalculiX/ccx_2.17/doc/ccx/ccx.html",\
+  #define     HELPFILE        {"/usr/local/CalculiX/cgx_2.21/doc/cgx/cgx.html",\
+    "/usr/local/CalculiX/ccx_2.21/doc/ccx/ccx.html",\
     "/usr/local/CalculiX/cgx_2.16/doc/aflib/aflib.pdf"}
   /* default tet mesher, 0:Netgen ng_vol, 1:tetgen */
   #define     TETMESHER  1
 #else
-  #define     HELPFILE        {"/usr/local/CalculiX/cgx_2.17/doc/cgx/cgx.html",\
-    "/usr/local/CalculiX/ccx_2.17/doc/ccx/ccx.html"}
+  #define     HELPFILE        {"/usr/local/CalculiX/cgx_2.21/doc/cgx/cgx.html",\
+    "/usr/local/CalculiX/ccx_2.21/doc/ccx/ccx.html"}
   /* default tet mesher, 0:Netgen ng_vol, 1:tetgen */
   #define     TETMESHER  1
 #endif
@@ -101,17 +115,22 @@
 #ifdef MTU
   #define     BROWSER         {"firefox"}
   #define     PSVIEWER         {"gv"}
+  #define     VIEWFORMAT         {"ps"}
   #define     ALLOW_SYS_FLAG   1
 #else
-/* #define     BROWSER         {"netscape"} */
-/*   #define     BROWSER         {"mozilla"} */
   #define     BROWSER         {"firefox"}
-/* #define     PSVIEWER         {"ghostview"} */
-  #define     PSVIEWER         {"gv"}
+  #ifdef WIN32
+    #define     PSVIEWER         {"mspaint.exe"}
+    #define     VIEWFORMAT       {"png"}
+  #else
+    #define     PSVIEWER         {"gv"}
+    #define     VIEWFORMAT       {"ps"}
+  #endif
   #define     ALLOW_SYS_FLAG   0
 #endif
 
 /* more parameters, better do not change them! */
+#define     MIN_ELEM_EDGE_DISTANCE 6e-5  /* elem edges vanish during zooming if smaller */
 #define     TEX_PIXELS  512          /* number of possible colors in texture mode */
 #define     GAMMA       1.9          /* gamma lightens or darkens an image (Hcpy) */
 #define     BLEND_ALPHA 0.33         /* default alpha used for blending */ 
@@ -131,7 +150,7 @@
 #define     NURS_TOLERANCE 30
 #define     NURS_TOLERANCE_PICK 80
 #define     NURS_ADD_AMBIG_PNTS 20   /* maximum expected points at ambiguous edge */
-#define     TOL_AMBIG  1.e-2        /* so close must a point lie to an ambiguous edge to be considered as ambiguous (trimming of nurbs) */
+#define     TOL_AMBIG  1.e-2        /* so close must a point be to an ambiguous edge to be considered as ambiguous (trimming of nurbs) */
 #define     MAX_PARAM_PER_RECORD 20 /* parameter per record in command files */
 #define     MAX_STACK_PARAMS 30     /* parameter to be written to the stack */
 #define     GL_FEEDBACK_BUFF_SIZE 3000000  /* size of the feedback buffer for nurbs-rendering */
@@ -158,7 +177,7 @@
 /*
 used fom material illumination
 */
-#define ILLUMINATE_RESULTS 0           /* 1: illumination of displayed results */
+#define ILLUMINATE_RESULTS 1           /* 1: illumination of displayed results */
 
 #define GAMB     0.5
 #define AMB      1.0
@@ -383,13 +402,14 @@ void printHash();
 int write2foam(char *setname, int strings, char **string, Summen *anz, Nodes *node, Faces *face, Elements *e_enqire, Sets *set, Datasets *lcase );
 int write2dolfyn(char *setname, int strings, char **string, Summen *anz, Nodes *node, Faces *face, Elements *e_enqire, Sets *set);
 int readFoam(char *datin, Summen *anz, Sets **sptr, Nodes **nptr, Elements **eptr, Datasets **lptr );
+int readVtk(char *datin, Summen *anz, Nodes **nptr, Elements **eptr, Datasets **lptr );
 int readAnsysList(char *datin, Summen *anz, Sets **sptr, Nodes **nptr, Elements **eptr, Datasets **lptr );
 
 /* writebp.c */
 int writebp(char *setname, Summen *anz, SumGeo *anzGeo, Points *pnt, Sets *set );
 
 /* writefbd.c */
-int writefbd(char *setname, Summen *anz, SumGeo *anzGeo, Points *pnt, Lines *line, Lcmb *lcmb, Gsur *surf, Gbod *body, Nurbs *nurs, Sets *set, Shapes *shape, Values *value, char *format );
+int writefbd(char *setname, char *format );
 void writeInit(FILE *handle);
 
 /* XFunktions_mesa.h */
@@ -455,7 +475,7 @@ int pre_line( char *record, int addFlag);
 void delLcmb( int anz, int *number );
 int lcmb_i( char *name, int add, int anz_l, char  *ori, int *lin );
 int  lcmb_( char *name, int add, int anz_l, char *ori, char *lin );
-void pre_lcmb( char *record, int addFlag);
+int pre_lcmb( char *record, int addFlag);
 void bak_delSurf( int anz, int *number );
 void delSurf( int anz, int *number );
 int  surface_i( char *name, char ori, int blend, int anz_c, char *cori, int *edge, char *typ );
@@ -484,7 +504,7 @@ void drawDispListEdges( GLuint list, int color, double width, char key, Nodes *n
 void drawFaces_edge( int num, int *name, Nodes *node, Faces *face, int col, char type );
 void drawElem_edge( int num, int *name, Nodes *node, Elements *e_enqire, int col, char type );
 void drawDispList( GLuint list, char key, Nodes *node, double *colNr );
-
+void DrawCommandLine(char *string, int curpos);
 
 
 
@@ -535,6 +555,7 @@ int enquireEntities(char *string);
 
 
 /* cgx.h */
+void DrawCommandLine(char *string, int curpos);
 void nodalDataset( int cur_entity, int lc, Summen *anz, Scale *scale, Nodes *node
 		   , Datasets *lcase, double *colNr, int scalaFlag );
 void elementDataset( int auswahl, int lc, Summen *anz, Scale *scale, Datasets *lcase, int offset, int maxIndex, int steps );
@@ -548,6 +569,7 @@ void frameSet(int setNrbuf);
 void menu( int selection );
 void createHardcopy( int selection, char *fileName );
 void updateDispLists(void);
+void set_cur_lc(int lc);
 void ConfigureAndShowWindow_Light(void);
 void ConfigureAndShowWindow_Load( void );
 void ConfigureAndShowWindow_Sequence(int dispFlag );
@@ -568,11 +590,14 @@ void createNewMainMenu(void);
 void recompileEntitiesInMenu(int pre_lc);
 void addDispToCoordinates( Nodes *nodes);
 void selectView( int selection );
+int createUSERparam(char *key, char *text);
 int createDSparam(int lc, char *key, char *text);
+int parser( char gkey, char *record, int *curshft, int commandLineFlag);
 void selectData( char *record);
 void specialKeyboard( int gkey, int x, int y );
 void Keyboard( unsigned char gkey, int x, int y );
 void moveModel(void);
+void DrawCommandLine(char *string, int curpos);
 void DrawGraficLoad( void );
 void DrawGraficLight( void );
 void DrawGraficAnimate( void );
@@ -589,10 +614,12 @@ void DrawMenuSequence( void );
 void DrawMenuLight( void );
 void DrawMenuAnimate( void );
 void DrawMenuSet( void );
+void updDrawingCube( void );
 void setWindowSize(char *string);
 void setWindowPos(char *string);
 void reshape( int width, int height );
 void initLight_rgb( void );
+void pre_subm( char *record);
 
 /* iniMeshData.h     */
 void vdsort ( int *a );
@@ -651,6 +678,7 @@ void qdel( void );
 void qrem( char *record);
 void qpnt( char *record);
 void qlin( char *record);
+void qmov( char *record);
 void qsur( char *record);
 void qbod( char *record);
 void qseq( char *record);
@@ -660,15 +688,16 @@ void qtxt(void);
 void moveText(int n, int x, int y);
 void moveNode(int n, int x, int y);
 void movePoint(GLuint *p, int x, int y);
+void moveSet(GLuint *p, int x, int y);
 int createFillet(int lin, double filletRadius);
 int createElem(int n);
 int createText( int nodenr, int x, int y );
 int createPoint( int x, int y );
 int normalLine(char *name, int *pnts, double l);
 int createLine( char *pnt, int flag );
-int splitSurf( int lmaster, int smaster );
+int splitSurf( int nl, int *ptr_lmaster, int smaster, int projFlag );
 int combineSurfs( int setNr );
-void convertLCMB( int lcmb );
+int convertLCMB( int lcmb );
 void convertLine( int line, int pickbuf );
 int intersect(int lin);
 int qsplitLine( int lin, int x, int y  );
@@ -689,6 +718,7 @@ void sendCflux( char *setname, char *format, Summen *anz, Nodes *node, Elements
 void sendDflux( char *setname, char *format, Summen *anz, Nodes *node, Elements *e_enqire, char *val1, char *val2, char *val3, char type );
 void sendSPC( char *setname, char *format, Summen *anz, Nodes *node, Elements *e_enqire, char *value, char *val1, char *val2, char *val3 );
 void sendSPCF( char *setname, char *format, Summen *anz, Nodes *node, Elements *e_enqire, char *value, char *val1, char *val2, char *val3 );
+void sendSKV( char *setname, char *format, Summen *anz, Nodes *node, Elements *e_enqire, char *val1, char *val2, char *val3 );
 void getNodeNormalen(int **sum_n, Nodes **norm, int setNr, Summen *anz, Faces *face);
 void sendSliders( char *setname, char *format, Summen *anz, Nodes *node, Elements *e_enqire, char *spcType );
 void sendSlidersf( char *setname, char *format, char *spcType );
@@ -748,7 +778,7 @@ int genSplitTrias(int trgtNr, Tri **ptr_tri, int flag );
 void pre_split( char *record);
 void pre_proj( char *record);
 void pre_proc( char *record);
-int splitLine(int l, int *l_nr, int ps_nr, double ps_lbez);
+int splitLine(int l, int *l_nr, int ps_nr);
 void  generateSetIndexes();
 int prnt(char *record);
 int  zap(char *record);
@@ -762,7 +792,7 @@ int commandoInterpreter( char *type, char *string, int na, int nb, FILE *handle1
 int getCommandLine(FILE *handle1, char **string1);
 int readfbd( char *datin, int addFlag );
 void readfrdfile( char *datin, char *setname );
-void pre_read( char *record );
+int pre_read( char *record );
 void createSuperSets(void);
 void pre_elty( char *record );
 void pre_eqal( char *record );
@@ -803,7 +833,7 @@ typedef struct {
 /* graph.c */
 void param2D(char *par1, int *dsNr, char *par2 );
 void plot2D(char *type, int setNr, int *dsNr, int entity );
-void graph( char *record);
+int  graph( char *record);
 
 /* corrad.c */
 void corrad( int setNr, double minradius);
@@ -827,7 +857,7 @@ int evalNurbs( int nr, int sum_p, double *pnt_u, double *pnt_v, Points *pnt);
 void cppfreearray(double *array);
 int createBlendedNurbs(int nr);
 void projSurfToNurbs( int nr, Gsur *surf, int snr, Nodes **node );
-void projSetToNurbs( int nr, Sets *set, int setNr, Points *pnt);
+void projSetToNurbs( int nr, Sets *set, int setNr, Points *pnt, Nodes **node);
 double *projPntsToNurbs( int nr, int anz_p, Points *pnt);
 double proj1PntToNurbs( int nr, double *pnt);
 int trimNurbs( int nr, int patch, double);
@@ -868,7 +898,7 @@ int deleteFreeEdges(Nodes *node, int *snods, int anz_n, Elements *elems, int anz
 int mesh_tr3g( int s );
 int determineBestCorners( int s, int *cl);
 int substituteSurf(int j);
-int meshSurf( int anz_s, int sindx, int snr, int *mapsurf, int meshflag, int renderFlag);
+int meshSurf( int anz_s, int sindx, int meshflag, int renderFlag);
 int meshSurfs( int setNr, int renderFlag );
 int evalBody( int b_indx, int *srefp );
 int fillBody( int b_indx, int **pn_uvw);
@@ -886,7 +916,7 @@ int surfMesh(int *imax, int *jmax, double *x, double *y, double *z);
 /*  bodyMesh2.h */
 int bodyMesh2(int *wmax, int *vmax, int *umax, double *x, double *y, double * z);
 
-/*  improveMesh.o */
+/*  improveMesh.h */
 int smooth_length( double *co, int *nk, int *kon, int *ne, int *iptr1, int *iptr2, int *nside, int *ineino, int *nkind, int *neigh, int *ndiv, double *pneigh, int *maxsumdiv, int *etyp, int *nori);
 int smooth_angle( double *co, int *nk, int *kon, int *ne, int *iptr1, int *iptr2, int *nside, int *ineino, int *nkind, int *neigh, int *ndiv, double *pneigh, int *maxsumdiv, int *etyp, int *nori);
 int smooth_midnodes( double *co, int *nk, int *kon, int *ne, int *iptr1, int *iptr2, int *nside, int *ineino, int *nkind, int *neigh, int *ndiv, double *pneigh, int *maxsumdiv, int *etyp, int *nori);
@@ -933,3 +963,8 @@ void pre_repSurf( int setNr);
 void *thread_repSurf( void *vargp);
 double calcGTOL(int setNr);
 int fillNurbsSurf(int nurbsnr, int nr);
+void moveLineEndPoint(int lineNr, int pntNr, double llength);
+int calcTrimLoops(int nurbsnr, int nr);
+int check_lineLoop(double *cg, int np, double *pnt_u, double *pnt_v, int e, int *tri);
+void mergeElem( int setNr, int delFlag );
+void DrawCommandLine(char *string, int curpos);
