@@ -96,7 +96,7 @@ void calcDatasets( int lc, Summen *anz, Nodes *node, Datasets *lcase )
   /* in case stress-phases for shells are to be regarded its necessary how much layers exist. All STRESP must show up first */
   if(( compare( lcase[lc].name, "STRESP", 6) == 6)&&(strlen(lcase[lc].name)==8)) layers=atoi(&lcase[lc].name[6])+1;
 
-  if( (compare( lcase[lc].name, "STRESS", 6) == 6)||(compare( lcase[lc].name, "PSTRESS", 6) == 6)||( compare( lcase[lc].name, "ZZS", 3) == 3)||(compare( lcase[lc].name, "MVSTRESS", 6) == 6)||(compare( lcase[lc].name, "SDSTRESS", 6) == 6)) stressFlag=1;
+  if( (compare( lcase[lc].name, "STRESS", 6) == 6)||(compare( lcase[lc].name, "PSTRESS", 6) == 6)||( compare( lcase[lc].name, "ZZS", 3) == 3)||(compare( lcase[lc].name, "MVSTRESS", 6) == 6)||(compare( lcase[lc].name, "SDSTRESS", 6) == 6)||(compare( lcase[lc].name, "STRNEG", 6) == 6)||(compare( lcase[lc].name, "STRMID", 6) == 6)||(compare( lcase[lc].name, "STRPOS", 6) == 6)) stressFlag=1;
 
   if( (compare( lcase[lc].name, "STRAIN", 6) == 6)||( compare( lcase[lc].name, "TOSTRAIN", 6) == 6)||( compare( lcase[lc].name, "MESTRAIN", 6) == 6)||( compare( lcase[lc].name, "ELSTRAIN", 6) == 6)||( compare( lcase[lc].name, "PLSTRAIN", 6) == 6)||( compare( lcase[lc].name, "CRSTRAIN", 6) == 6)||( compare( lcase[lc].name, "LE", 2) == 2)) stressFlag=0;
 
@@ -2062,7 +2062,17 @@ void generateDataset( Summen *anz, Datasets **ptr_lcase, char *name, int ncomps,
   int i,n;
   int anz_l;
   Datasets *lcase;
+  double fbuf[1];
+  int dbuf[2];
+  char sbuf[3][MAX_LINE_LENGTH];
 
+  // this values could have been be stored at addresses which could change due to the following realloc((Datasets *)lcase
+  fbuf[0]=value;
+  sprintf(sbuf[0],"%s",name);
+  sprintf(sbuf[1],"%s",dataset_text);
+  sprintf(sbuf[2],"%s",analysis_name);
+  dbuf[0]=step_number;
+  dbuf[1]=analysis_type;
   lcase=*ptr_lcase;
 
   /* change the current dataset if ncomps==0 */
@@ -2109,8 +2119,8 @@ void generateDataset( Summen *anz, Datasets **ptr_lcase, char *name, int ncomps,
          printf("\n\n ERROR: malloc failed\n\n" );
       if ( (lcase[anz->l].icname[i] = (char *)malloc( MAX_LINE_LENGTH * sizeof(char))) == NULL )
          printf("\n\n ERROR: malloc failed\n\n" );
-      lcase[anz->l].max[i]=-MAX_INTEGER;
-      lcase[anz->l].min[i]=MAX_INTEGER;
+      lcase[anz->l].max[i]=-MAX_FLOAT;
+      lcase[anz->l].min[i]=MAX_FLOAT;
       lcase[anz->l].nmax[i]=0;
       lcase[anz->l].nmin[i]=0;
       for(n=0; n<=anz->nmax; n++)
@@ -2136,12 +2146,12 @@ void generateDataset( Summen *anz, Datasets **ptr_lcase, char *name, int ncomps,
       sprintf( lcase[anz->l].compName[i],"unused");
     }
   }
-  lcase[anz->l].value  = value;
-  strcpy(lcase[anz->l].name, name) ;
-  strcpy(lcase[anz->l].dataset_text, dataset_text);
-  strcpy(lcase[anz->l].analysis_name, analysis_name);
-  lcase[anz->l].step_number= step_number;
-  lcase[anz->l].analysis_type=analysis_type;
+  lcase[anz->l].value  = fbuf[0];
+  strcpy(lcase[anz->l].name, sbuf[0]) ;
+  strcpy(lcase[anz->l].dataset_text, sbuf[1]);
+  strcpy(lcase[anz->l].analysis_name, sbuf[2]);
+  lcase[anz->l].step_number=dbuf[0];
+  lcase[anz->l].analysis_type=dbuf[1];
 
   if(!ncomps)
   {
@@ -2150,7 +2160,7 @@ void generateDataset( Summen *anz, Datasets **ptr_lcase, char *name, int ncomps,
   else
   {
     *ptr_lcase=lcase;
-    cur_lc=anz->l;
+    set_cur_lc(anz->l);
     anz->l++;
   }
 }
