@@ -8,14 +8,14 @@
 /* liest einen Record bis '\n'; uebergibt Anzahl gelesene Zeichen */
 int frecord( FILE *handle1,  char *string)
 {
-  register int i, n, c;
+  int i, c;
 
   for (i=0; i<MAX_LINE_LENGTH-1; i++)
   {
     string[i] = getc(handle1);
     if (string[i] == '\n')
       {
-      for (n=i+1; n<MAX_LINE_LENGTH; ++n) string[n] = '\0';
+      string[i+1] = '\0';
       return(i);
       }
     if (string[i] == '\r')
@@ -24,12 +24,12 @@ int frecord( FILE *handle1,  char *string)
       if (c != '\n')
         ungetc(c, handle1);
 
-      for (n=i+1; n<MAX_LINE_LENGTH; ++n) string[n] = '\0';
+      string[i+1] = '\0';
       return(i);
      }
     else if (string[i] == (char)EOF)
       {
-      for (n=i+1; n<MAX_LINE_LENGTH; ++n) string[n] = '\0';
+      string[i+1] = '\0';
       return(i);
       }
   }
