@@ -705,7 +705,7 @@ int generateTetFromBody(int nr, double teth, int eattr, int mesherFlag)
   for (k = 0; k < set[mnodSet].anz_n; k++) setr(setNr,"n",set[mnodSet].node[k]);
 
   /* add to body */
-  if((body[nr].nod=(int *)realloc((int *)body[nr].nod, (set[setNr].anz_n)*sizeof(int)) )==NULL)
+  if((body[nr].nod=(int *)realloc((int *)body[nr].nod, (set[setNr].anz_n+1)*sizeof(int)) )==NULL)
   { printf(" ERROR: realloc failure in generateTet body:%s can not be meshed\n\n" , body[nr].name); return(0); }
   for (k = 0; k < set[setNr].anz_n; k++) body[nr].nod[k]=set[setNr].node[k];
   body[nr].nn=set[setNr].anz_n;
