@@ -50,6 +50,7 @@ extern double dx ,dy;                                      /* Mauskoordinaten */
 extern int   steps;                   /* Schrittweite der Farbscala, und NURB aufloesung */
 extern double gtol;
 extern char  picture_text[MAX_LINE_LENGTH], datin[MAX_LINE_LENGTH];
+extern char  viewformat[MAX_LINE_LENGTH];           /*  viewformat: ps,png */
 extern char  psviewer[MAX_LINE_LENGTH];
 extern char  delPntFlag;                    /* 1: deleted points exists */
 extern char  delLineFlag;                   /* 1: deleted lines exists */
@@ -92,7 +93,8 @@ extern CopiedNodeSets copiedNodeSets[1];
 extern char  addDispFlag;                    /* 0: original node-coordinates, 1: node-coordinates+displacements */
 extern SpecialSet specialset[1];
 
-int graph_Nr=-1;
+extern int graph_Nr;
+extern int graph_on; 
 
 
 void length2D(int setNr, int dsNr, int entity )
@@ -128,22 +130,26 @@ void length2D(int setNr, int dsNr, int entity )
   sprintf(buffer, "graph_%d.gnu", graph_Nr);
   handle_gnu = fopen (buffer, "w+b" );
   if (handle_gnu==NULL) { printf ("\nThe output file \"%s\" could not be opened.\n\n",buffer); return;}
-#ifdef WIN32
-  fprintf(handle_gnu, "set term png\n");
-  sprintf(buffer, "graph_%d.png", graph_Nr);
-  fprintf(handle_gnu, "set out \"%s\"\n", buffer);
-  fprintf(handle_gnu, "set grid\n");
-  fprintf(handle_gnu, "set title \"Values at Nodes\"\n");
-#else
-  fprintf(handle_gnu, "set term postscript landscape monochrom  \n");
-  fprintf(handle_gnu, "#set term x11 \n");
-  sprintf(buffer, "graph_%d.ps", graph_Nr);
-  fprintf(handle_gnu, "set out \"%s\"\n", buffer);
-  fprintf(handle_gnu, "set grid\n");
-  fprintf(handle_gnu, "set title \"Values at Nodes (%s)\"\n", datin);
-#endif
+  if((viewformat[0]=='p')&&(viewformat[1]=='n'))
+  {
+    fprintf(handle_gnu, "set term png\n");
+    sprintf(buffer, "graph_%d.png", graph_Nr);
+    fprintf(handle_gnu, "set out \"%s\"\n", buffer);
+    fprintf(handle_gnu, "set grid\n");
+    fprintf(handle_gnu, "set title \"Values at Nodes\"\n");
+  }
+  else if((viewformat[0]=='p')&&(viewformat[1]=='s'))
+  {
+    fprintf(handle_gnu, "set term postscript landscape monochrom noenhanced \n");
+    fprintf(handle_gnu, "#set term x11 \n");
+    sprintf(buffer, "graph_%d.ps", graph_Nr);
+    fprintf(handle_gnu, "set out \"%s\"\n", buffer);
+    fprintf(handle_gnu, "set grid\n");
+    fprintf(handle_gnu, "set title \"Values at Nodes (%s)\"\n", datin);
+  }
+  else printf(" ERROR: Format not known:%s please set either ps or png with 'asgn viewformat'\n",viewformat);
+  
   fprintf(handle_gnu, "set ylabel \" %s \"\n", lcase[dsNr].compName[entity]);
-
   sprintf(buffer, "graph_%d.out", graph_Nr);
   fprintf(handle_gnu, "set xlabel \" Length \"\n");
   fprintf(handle_gnu, "plot ");
@@ -151,23 +157,31 @@ void length2D(int setNr, int dsNr, int entity )
 
   fclose(handle_gnu);
 
-
+  if((viewformat[0]=='p')&&(viewformat[1]=='n'))
+  {
+    sprintf(buffer, "graph_%d.png", graph_Nr);
+    printf ("write %s \n", buffer);
+    sprintf(buffer, "gnuplot graph_%d.gnu", graph_Nr );
+    system (buffer);
 #ifdef WIN32
-  sprintf(buffer, "graph_%d.png", graph_Nr);
-  printf ("write %s \n", buffer);
-  sprintf(buffer, "gnuplot graph_%d.gnu", graph_Nr );
-  system (buffer);
-// if(inpformat) sprintf(buffer, "%s graph_%d.png &", psviewer, graph_Nr );
-  if(inpformat) sprintf(buffer, "graph_%d.png &", graph_Nr );
-  system (buffer);
+    //if((inpformat)&&(graph_on)) sprintf(buffer, "%s graph_%d.png &", psviewer, graph_Nr );
+    if((inpformat)&&(graph_on)) sprintf(buffer, "graph_%d.png &", graph_Nr );
+    system (buffer);
 #else
-  sprintf(buffer, "graph_%d.ps", graph_Nr);
-  printf ("write %s \n", buffer);
-  sprintf(buffer, "gnuplot graph_%d.gnu", graph_Nr );
-  system (buffer);
-  if(inpformat) sprintf(buffer, "%s graph_%d.ps &", psviewer, graph_Nr );
-  system (buffer);
+    if((inpformat)&&(graph_on)) sprintf(buffer, "%s graph_%d.png &", psviewer, graph_Nr );
+    system (buffer);
 #endif
+  }
+  else if((viewformat[0]=='p')&&(viewformat[1]=='s'))
+  {
+    sprintf(buffer, "graph_%d.ps", graph_Nr);
+    printf ("write %s \n", buffer);
+    sprintf(buffer, "gnuplot graph_%d.gnu", graph_Nr );
+    system (buffer);
+    if((inpformat)&&(graph_on)) sprintf(buffer, "%s graph_%d.ps &", psviewer, graph_Nr );
+    system (buffer);
+  }
+  else printf(" ERROR: Format not known:%s please set either ps or png with 'asgn viewformat'\n",viewformat);
   printf ("ready \n");
 }
 
@@ -252,20 +266,25 @@ void param2D(char *par1, int *dsNr, char *par2 )
   handle_gnu = fopen (buffer, "w+b" );
   if (handle_gnu==NULL) { printf ("\nThe output file \"%s\" could not be opened.\n\n",
      buffer); return;}
-#ifdef WIN32
-  fprintf(handle_gnu, "set term png\n");
-  sprintf(buffer, "graph_%d.png", graph_Nr);
-  fprintf(handle_gnu, "set out \"%s\"\n", buffer);
-  fprintf(handle_gnu, "set grid\n");
+  if((viewformat[0]=='p')&&(viewformat[1]=='n'))
+  {
+    fprintf(handle_gnu, "set term png\n");
+    sprintf(buffer, "graph_%d.png", graph_Nr);
+    fprintf(handle_gnu, "set out \"%s\"\n", buffer);
+    fprintf(handle_gnu, "set grid\n");
 //  fprintf(handle_gnu, "set title \"File:%s\"\n", datin);
-#else
-  fprintf(handle_gnu, "set term postscript landscape monochrom  \n");
-  fprintf(handle_gnu, "#set term x11 \n");
-  sprintf(buffer, "graph_%d.ps", graph_Nr);
-  fprintf(handle_gnu, "set out \"%s\"\n", buffer);
-  fprintf(handle_gnu, "set grid\n");
-  fprintf(handle_gnu, "set title \"File:%s\"\n", datin);
-#endif
+  }
+  else if((viewformat[0]=='p')&&(viewformat[1]=='s'))
+  {
+    fprintf(handle_gnu, "set term postscript landscape monochrom noenhanced \n");
+    fprintf(handle_gnu, "#set term x11 \n");
+    sprintf(buffer, "graph_%d.ps", graph_Nr);
+    fprintf(handle_gnu, "set out \"%s\"\n", buffer);
+    fprintf(handle_gnu, "set grid\n");
+    fprintf(handle_gnu, "set title \"File:%s\"\n", datin);
+  }
+  else printf(" ERROR: Format not known:%s please set either ps or png with 'asgn viewformat'\n",viewformat);
+
   fprintf(handle_gnu, "set xlabel \" %s \"\n", par1);
   fprintf(handle_gnu, "set ylabel \" %s \"\n", par2);
 
@@ -274,28 +293,37 @@ void param2D(char *par1, int *dsNr, char *par2 )
   fprintf(handle_gnu, "plot ");
   for (i=0; i<anz_val-1; i++)
   {
-    fprintf(handle_gnu, "\"%s\" using 1:%d title 'val%d' with linespoints, ", buffer, i+2, i+1);
+    fprintf(handle_gnu, "\"%s\" using 1:%d title 'val%d' with linespoints pt %d, ", buffer, i+2, i+1, i+1);
   }
-  fprintf(handle_gnu, "\"%s\" using 1:%d title 'val%d' with linespoints\n", buffer, i+2, i+1);
+  fprintf(handle_gnu, "\"%s\" using 1:%d title 'val%d' with linespoints pt %d\n", buffer, i+2, i+1, i+1);
   fprintf(handle_gnu, "\n");
   fclose(handle_gnu);
 
+  if((viewformat[0]=='p')&&(viewformat[1]=='n'))
+  {
+    sprintf(buffer, "graph_%d.png", graph_Nr);
+    printf ("write %s \n", buffer);
+    sprintf(buffer, "gnuplot graph_%d.gnu", graph_Nr );
+    system (buffer);
 #ifdef WIN32
-  sprintf(buffer, "graph_%d.png", graph_Nr);
-  printf ("write %s \n", buffer);
-  sprintf(buffer, "gnuplot graph_%d.gnu", graph_Nr );
-  system (buffer);
-// if(inpformat)  sprintf(buffer, "%s graph_%d.png &", psviewer, graph_Nr );
-  if(inpformat) sprintf(buffer, "graph_%d.png &", graph_Nr );
-  system (buffer);
+    //if((inpformat)&&(graph_on))   sprintf(buffer, "%s graph_%d.png &", psviewer, graph_Nr );
+    if((inpformat)&&(graph_on))  sprintf(buffer, "graph_%d.png &", graph_Nr );
+    system (buffer);
 #else
-  sprintf(buffer, "graph_%d.ps", graph_Nr);
-  printf ("write %s \n", buffer);
-  sprintf(buffer, "gnuplot graph_%d.gnu", graph_Nr );
-  system (buffer);
-  if(inpformat) sprintf(buffer, "%s graph_%d.ps &", psviewer, graph_Nr );
-  system (buffer);
+    if((inpformat)&&(graph_on))   sprintf(buffer, "%s graph_%d.png &", psviewer, graph_Nr );
+    system (buffer);
 #endif
+  }
+  else if((viewformat[0]=='p')&&(viewformat[1]=='s'))
+  {
+    sprintf(buffer, "graph_%d.ps", graph_Nr);
+    printf ("write %s \n", buffer);
+    sprintf(buffer, "gnuplot graph_%d.gnu", graph_Nr );
+    system (buffer);
+    if((inpformat)&&(graph_on))  sprintf(buffer, "%s graph_%d.ps &", psviewer, graph_Nr );
+    system (buffer);
+  }
+  else printf(" ERROR: Format not known:%s please set either ps or png with 'asgn viewformat'\n",viewformat);
 
   printf ("ready \n");
 }
@@ -371,16 +399,31 @@ void plot2D(char *type, int setNr, int *dsNr, int entity )
     /* check if the data of the specified lcase (Dataset) are already available */
     if (!lcase[lc].loaded)
     {
-      if ( (lcase[lc].dat = (float **)malloc( (lcase[lc].ncomps) * sizeof(float *))) == NULL )
-        printf("\n\n ERROR: malloc failure\n\n" );
-      for(j=0; j<(lcase[lc].ncomps); j++)
-      {
-        if ( (lcase[lc].dat[j] = (float *)malloc( (anz->nmax+1) * sizeof(float))) == NULL )
-          printf("\n\n ERROR: malloc failure\n\n" );	               
-        for(n=0; n<=anz->nmax; n++) lcase[lc].dat[j][n]=0.;
-      }
-      lcase[lc].loaded=1;
 
+      if(copiedNodeSets[0].sets)
+      {
+	// copy Datasets to copied nodes (slow, since all nodes of the dataset are loaded)
+        if( pre_readfrdblock(copiedNodeSets , lc, anz, node, lcase )==-1) 
+        {
+          printf("ERROR in graph: Could not read data for Dataset:%d\n", lc+1); 
+          return;
+        }
+        calcDatasets( lc, anz, node, lcase );
+      }
+      else
+      {
+        if ( (lcase[lc].dat = (float **)malloc( (lcase[lc].ncomps) * sizeof(float *))) == NULL )
+          printf("\n\n ERROR: malloc failure\n\n" );
+        for(j=0; j<(lcase[lc].ncomps); j++)
+        {
+          if ( (lcase[lc].dat[j] = (float *)malloc( (anz->nmax+1) * sizeof(float))) == NULL )
+            printf("\n\n ERROR: malloc failure\n\n" );	               
+          for(n=0; n<=anz->nmax; n++) lcase[lc].dat[j][n]=0.;
+        }
+        //lcase[lc].loaded=1;
+      }
+      
+      
       if(setcut>-1)
       {
         delSet(specialset->tmp);
@@ -399,7 +442,8 @@ void plot2D(char *type, int setNr, int *dsNr, int entity )
         for ( n=0; n<set[settmp].anz_n; n++)
         {
           if(readOneNode( lc, anz, lcase, set[settmp].node[n], &vptr, &offset[n] )==-1)
-            printf(" ERROR: readOneNode could not find node:%d\n", set[settmp].node[n]);
+            ;
+	  //printf(" ERROR: readOneNode could not find node:%d\n", set[settmp].node[n]);
           else
 	  {
             for(j=0; j<lcase[lc].ncomps; j++)  lcase[lc].dat[j][set[settmp].node[n]] = vptr[j] ;
@@ -425,7 +469,8 @@ void plot2D(char *type, int setNr, int *dsNr, int entity )
         for ( n=0; n<set[setNr].anz_n; n++)
         {
           if(readOneNode( lc, anz, lcase, set[setNr].node[n], &vptr, &offset[n] )==-1)
-            printf(" ERROR: readOneNode could not find node:%d\n", set[setNr].node[n]);
+	    ;
+	  //printf(" ERROR: readOneNode could not find node:%d\n", set[setNr].node[n]);
           else
 	  {
             for(j=0; j<lcase[lc].ncomps; j++)  lcase[lc].dat[j][set[setNr].node[n]] = vptr[j] ;
@@ -542,7 +587,7 @@ void plot2D(char *type, int setNr, int *dsNr, int entity )
   for (lc=0; lc<anz_lc; lc++)
   {
     //fprintf (handle_out, "%-5d %-12.5e %f ", lc+1, lc_time[lc], atof(lc_description[lc]));
-    fprintf (handle_out, "%-5d %-5d %-12.5e %f ", lc_step[lc], dsNr[lc]+1, lc_time[lc], atof(lc_description[lc]));
+    fprintf (handle_out, "%-5d %-5d %-12.5e %f ", lc_step[lc], dsNr[lc+1]+1, lc_time[lc], atof(lc_description[lc]));
     for ( n=0; n<set[setNr].anz_n; n++)
       fprintf (handle_out, "%-12.5e ", dat[n][lc]);
     fprintf (handle_out, "\n");
@@ -572,18 +617,23 @@ void plot2D(char *type, int setNr, int *dsNr, int entity )
   handle_gnu = fopen (buffer, "w+b" );
   if (handle_gnu==NULL) { printf ("\nThe output file \"%s\" could not be opened.\n\n",
      buffer); return;}
-#ifdef WIN32
-  fprintf(handle_gnu, "set term png\n");
-  sprintf(buffer, "graph_%d.png", graph_Nr);
-  fprintf(handle_gnu, "set out \"%s\"\n", buffer);
-  fprintf(handle_gnu, "set title \"Values at Nodes\"\n");
-#else
-  fprintf(handle_gnu, "set term postscript landscape monochrom  \n");
-  fprintf(handle_gnu, "#set term x11 \n");
-  sprintf(buffer, "graph_%d.ps", graph_Nr);
-  fprintf(handle_gnu, "set out \"%s\"\n", buffer);
-  fprintf(handle_gnu, "set title \"Values at Nodes (%s)\"\n", datin);
-#endif
+  if((viewformat[0]=='p')&&(viewformat[1]=='n'))
+  {
+    fprintf(handle_gnu, "set term png\n");
+    sprintf(buffer, "graph_%d.png", graph_Nr);
+    fprintf(handle_gnu, "set out \"%s\"\n", buffer);
+    fprintf(handle_gnu, "set title \"Values at Nodes\"\n");
+  }
+  else if((viewformat[0]=='p')&&(viewformat[1]=='s'))
+  {
+    fprintf(handle_gnu, "set term postscript landscape monochrom noenhanced \n");
+    fprintf(handle_gnu, "#set term x11 \n");
+    sprintf(buffer, "graph_%d.ps", graph_Nr);
+    fprintf(handle_gnu, "set out \"%s\"\n", buffer);
+    fprintf(handle_gnu, "set title \"Values at Nodes (%s)\"\n", datin);
+  }
+  else printf(" ERROR: Format not known:%s please set either ps or png with 'asgn viewformat'\n",viewformat);
+
   fprintf(handle_gnu, "set grid\n");
   fprintf(handle_gnu, "set ylabel \" %s \"\n", lcase[dsNr[1]].compName[entity]);
 
@@ -594,11 +644,11 @@ void plot2D(char *type, int setNr, int *dsNr, int entity )
     fprintf(handle_gnu, "plot ");
     for (n=0; n<set[setNr].anz_n-1; n++)
     {
-      fprintf(handle_gnu, "\"%s\" using 1:%d title 'Node=%d' with linespoints, ",
-            buffer, n+5, set[setNr].node[n]);
+      fprintf(handle_gnu, "\"%s\" using 1:%d title 'Node=%d' with linespoints pt %d, ",
+	      buffer, n+5, set[setNr].node[n], n+1);
     }
-    fprintf(handle_gnu, "\"%s\" using 1:%d title 'Node=%d' with linespoints\n",
-            buffer, n+5, set[setNr].node[n]);
+    fprintf(handle_gnu, "\"%s\" using 1:%d title 'Node=%d' with linespoints pt %d\n",
+            buffer, n+5, set[setNr].node[n], n+1);
   }
   else if((type[0]=='N')||(type[0]=='n'))
   {
@@ -606,11 +656,11 @@ void plot2D(char *type, int setNr, int *dsNr, int entity )
     fprintf(handle_gnu, "plot ");
     for (n=0; n<set[setNr].anz_n-1; n++)
     {
-      fprintf(handle_gnu, "\"%s\" using 2:%d title 'Node=%d' with linespoints, ",
-            buffer, n+5, set[setNr].node[n]);
+      fprintf(handle_gnu, "\"%s\" using 2:%d title 'Node=%d' with linespoints pt %d, ",
+            buffer, n+5, set[setNr].node[n], n+1);
     }
-    fprintf(handle_gnu, "\"%s\" using 2:%d title 'Node=%d' with linespoints\n",
-            buffer, n+5, set[setNr].node[n]);
+    fprintf(handle_gnu, "\"%s\" using 2:%d title 'Node=%d' with linespoints pt %d\n",
+            buffer, n+5, set[setNr].node[n], n+1);
   }
   else if((type[0]=='T')||(type[0]=='t')||(type[0]=='F')||(type[0]=='j'))
   {
@@ -619,11 +669,11 @@ void plot2D(char *type, int setNr, int *dsNr, int entity )
     fprintf(handle_gnu, "plot ");
     for (n=0; n<set[setNr].anz_n-1; n++)
     {
-      fprintf(handle_gnu, "\"%s\" using 3:%d title 'Node=%d' with linespoints, ",
-            buffer, n+5, set[setNr].node[n]);
+      fprintf(handle_gnu, "\"%s\" using 3:%d title 'Node=%d' with linespoints pt %d, ",
+            buffer, n+5, set[setNr].node[n], n+1);
     }
-    fprintf(handle_gnu, "\"%s\" using 3:%d title 'Node=%d' with linespoints\n ",
-            buffer, n+5, set[setNr].node[n]);
+    fprintf(handle_gnu, "\"%s\" using 3:%d title 'Node=%d' with linespoints pt %d\n ",
+            buffer, n+5, set[setNr].node[n], n+1);
   }
   else if((type[0]=='D')||(type[0]=='d'))
   {
@@ -631,11 +681,11 @@ void plot2D(char *type, int setNr, int *dsNr, int entity )
     fprintf(handle_gnu, "plot ");
     for (n=0; n<set[setNr].anz_n-1; n++)
     {
-      fprintf(handle_gnu, "\"%s\" using 4:%d title 'Node=%d' with linespoints, ",
-            buffer, n+5, set[setNr].node[n]);
+      fprintf(handle_gnu, "\"%s\" using 4:%d title 'Node=%d' with linespoints pt %d, ",
+            buffer, n+5, set[setNr].node[n], n+1);
     }
-    fprintf(handle_gnu, "\"%s\" using 4:%d title 'Node=%d' with linespoints\n ",
-            buffer, n+5, set[setNr].node[n]);
+    fprintf(handle_gnu, "\"%s\" using 4:%d title 'Node=%d' with linespoints pt %d\n ",
+            buffer, n+5, set[setNr].node[n], n+1);
   }
   else
   {
@@ -643,31 +693,40 @@ void plot2D(char *type, int setNr, int *dsNr, int entity )
     fprintf(handle_gnu, "plot ");
     for (n=0; n<set[setNr].anz_n-1; n++)
     {
-      fprintf(handle_gnu, "\"%s\" using 3:%d title 'Node=%d' with linespoints, ",
-            buffer, n+5, set[setNr].node[n]);
+      fprintf(handle_gnu, "\"%s\" using 3:%d title 'Node=%d' with linespoints pt %d, ",
+            buffer, n+5, set[setNr].node[n], n+1);
     }
-    fprintf(handle_gnu, "\"%s\" using 3:%d title 'Node=%d' with linespoints\n ",
-            buffer, n+5, set[setNr].node[n]);
+    fprintf(handle_gnu, "\"%s\" using 3:%d title 'Node=%d' with linespoints pt %d\n ",
+            buffer, n+5, set[setNr].node[n], n+1);
   }
 
   fclose(handle_gnu);
 
+  if((viewformat[0]=='p')&&(viewformat[1]=='n'))
+  {
+    sprintf(buffer, "graph_%d.png", graph_Nr);
+    printf ("write %s \n", buffer);
+    sprintf(buffer, "gnuplot graph_%d.gnu", graph_Nr );
+    system (buffer);
 #ifdef WIN32
-  sprintf(buffer, "graph_%d.png", graph_Nr);
-  printf ("write %s \n", buffer);
-  sprintf(buffer, "gnuplot graph_%d.gnu", graph_Nr );
-  system (buffer);
-// if(inpformat)  sprintf(buffer, "%s graph_%d.png &", psviewer, graph_Nr );
-  if(inpformat) sprintf(buffer, "graph_%d.png &", graph_Nr );
-  system (buffer);
+    //if((inpformat)&&(graph_on))  sprintf(buffer, "%s graph_%d.png &", psviewer, graph_Nr );
+    if((inpformat)&&(graph_on))  sprintf(buffer, "graph_%d.png &", graph_Nr );
+    system (buffer);
 #else
-  sprintf(buffer, "graph_%d.ps", graph_Nr);
-  printf ("write %s \n", buffer);
-  sprintf(buffer, "gnuplot graph_%d.gnu", graph_Nr );
-  system (buffer);
-  if(inpformat) sprintf(buffer, "%s graph_%d.ps &", psviewer, graph_Nr );
-  system (buffer);
+    if((inpformat)&&(graph_on))   sprintf(buffer, "%s graph_%d.png &", psviewer, graph_Nr );
+    system (buffer);
 #endif
+  }
+  else if((viewformat[0]=='p')&&(viewformat[1]=='s'))
+  {
+    sprintf(buffer, "graph_%d.ps", graph_Nr);
+    printf ("write %s \n", buffer);
+    sprintf(buffer, "gnuplot graph_%d.gnu", graph_Nr );
+    system (buffer);
+    if((inpformat)&&(graph_on))  sprintf(buffer, "%s graph_%d.ps &", psviewer, graph_Nr );
+    system (buffer);
+  }
+  else printf(" ERROR: Format not known:%s please set either ps or png with 'asgn viewformat'\n",viewformat);
 
   for (i=0; i<set[setNr].anz_n; i++)  free(dat[i]);
   free(dat);
@@ -677,7 +736,7 @@ void plot2D(char *type, int setNr, int *dsNr, int entity )
 
 
 
-void graph( char *record)
+int graph( char *record)
 {
   int  i,j,n,c,l,length=0, indx=0, nr, sum;
   int lc, *dsNr=NULL, anz_lc=0, eNr=-1, seq=-1;
@@ -688,7 +747,7 @@ void graph( char *record)
   char addDispFlagLocal=0, zapFlag=0;
 
   int   copyset, copyseq, shellset, maxn=0, minn=0, jj;
-  double gtolbuf, nref[3], vnrefn[3], dist, maxdist, mindist;
+  double gtolbuf, nref[3], vnrefn[3], dist, maxdist, mindist, buf;
   double vn1[3],vn2[3]; 
   
   FILE *handle_out, *handle_gnu;
@@ -696,7 +755,7 @@ void graph( char *record)
   dataset[0]=entity[0]=0;
   length=sscanf( record, "%s%s%s%s%d%d", name, type, dataset, entity, &lcmin, &lcmax );
   lcmin--; lcmax--;
-  if(!anz->l) { printf(" ERROR: No datasets available\n"); return; }
+  if(!anz->l) { printf(" ERROR: No datasets available\n"); return(-1); }
   if(lcmax<0) lcmax=anz->l-1;
   if(lcmax>anz->l) lcmax=anz->l-1;
   if(lcmin<0) lcmin=0;
@@ -712,7 +771,7 @@ void graph( char *record)
     if (indx<0)
     {
       errMsg(" ERROR: Set (%s) is undefined\n", name );
-      return;
+      return(-1);
     }
     strcpy(buffer,name);
 
@@ -858,7 +917,7 @@ void graph( char *record)
 	delSet("-shellelems");
       }
     }
-    else if (set[indx].anz_n>0)
+    else if((set[indx].anz_n>0)&&(set[indx].type==0))
     {
       /* open a node set */
       /* generate a name based on the setname */
@@ -888,7 +947,7 @@ void graph( char *record)
       nref[0]/=set[indx].anz_n;
       nref[1]/=set[indx].anz_n;
       nref[2]/=set[indx].anz_n;
-      maxdist=0.;
+     maxdist=0.;
       for (j=0; j<set[indx].anz_n; j++)
       {
         n=set[indx].node[j];
@@ -938,7 +997,7 @@ void graph( char *record)
       }
 
       /* load the final seq */
-      if(type[0]=='+')
+      if(type[0]!='-')
       {
         for (j=0; j<set[copyseq].anz_n; j++)
         {
@@ -975,7 +1034,7 @@ void graph( char *record)
       zap(specialset->nompc);
       */
     }
-    else if (set[indx].type>0)
+    else if((set[indx].anz_n>0)&&(set[indx].type>0))
     {
       /* open a node sequence */
       /* generate a name based on the setname */
@@ -983,7 +1042,7 @@ void graph( char *record)
       seq=getSetNr(name);
       if(seq>-1) getNewName(name,"se");
       seq=pre_seta(name,"is",0);
-      if(type[0]=='+')
+      if(type[0]!='-')
       {
         for (j=0; j<set[indx].anz_n; j++)
         {
@@ -1027,7 +1086,7 @@ void graph( char *record)
         addDispToCoordinates(node);
       }
       errMsg(" ERROR: Set (%s) contains no lcmb or line and is no sequence of nodes\n", name );
-      return;
+      return(-1);
     }
 
     /* compile the lc-data based on a previous lc-selection */
@@ -1036,9 +1095,13 @@ void graph( char *record)
     printf("ds:%d e:%d\n", lc+1, eNr+1);
     length2D( seq, lc, eNr);
 
-    /* delete a temporary sequence created for the line mapping */ 
-    if (zapFlag) zap(set[seq].name);
-    else delSet(set[seq].name);
+    /* delete a temporary sequence created for the line mapping */
+    if((type[0]=='c')||(type[1]=='c')); // just keep the sequence
+    else
+    {
+      if (zapFlag) zap(set[seq].name);
+      else delSet(set[seq].name);
+    }
   }
   else if (compare(type, "amp", 1)==1)
   {
@@ -1061,7 +1124,7 @@ void graph( char *record)
       if(indx==-1) continue;
       sprintf(buffer, "%s.out",amplitude[nr].name);
       handle_out = fopen (buffer, "w+b" );
-      if (handle_out==NULL) { printf ("\nThe output file \"%s\" could not be opened.\n\n", buffer); return;}
+      if (handle_out==NULL) { printf ("\nThe output file \"%s\" could not be opened.\n\n", buffer); return(-1);}
       for (i=0; i<amplitude[indx].n; i++)
       {
         fprintf (handle_out, "%d %e %e\n", i+1, amplitude[indx].x[i],amplitude[indx].y[i]);
@@ -1077,17 +1140,22 @@ void graph( char *record)
 
     sprintf(buffer, "amplitude.gnu");
     handle_gnu = fopen (buffer, "w+b" );
-    if (handle_gnu==NULL) { printf ("\nThe output file \"%s\" could not be opened.\n\n",buffer); return;}
-#ifdef WIN32
-    fprintf(handle_gnu, "set term png\n");
-    sprintf(buffer, "amplitude.png", graph_Nr);
-    fprintf(handle_gnu, "set out \"%s\"\n", buffer);
-#else
-    fprintf(handle_gnu, "set term postscript landscape monochrom  \n");
-    fprintf(handle_gnu, "#set term x11 \n");
-    sprintf(buffer, "amplitude.ps");
-    fprintf(handle_gnu, "set out \"%s\"\n", buffer);
-#endif
+    if (handle_gnu==NULL) { printf ("\nThe output file \"%s\" could not be opened.\n\n",buffer); return(-1);}
+    if((viewformat[0]=='p')&&(viewformat[1]=='n'))
+    {
+      fprintf(handle_gnu, "set term png\n");
+      sprintf(buffer, "amplitude.png");
+      fprintf(handle_gnu, "set out \"%s\"\n", buffer);
+    }
+    else if((viewformat[0]=='p')&&(viewformat[1]=='s'))
+    {
+      fprintf(handle_gnu, "set term postscript landscape monochrom noenhanced \n");
+      fprintf(handle_gnu, "#set term x11 \n");
+      sprintf(buffer, "amplitude.ps");
+      fprintf(handle_gnu, "set out \"%s\"\n", buffer);
+    }
+    else printf(" ERROR: Format not known:%s please set either ps or png with 'asgn viewformat'\n",viewformat);
+
     fprintf(handle_gnu, "set grid\n");
     fprintf(handle_gnu, "set title \"Amplitude\"\n");
     fprintf(handle_gnu, "set ylabel \" y \"\n");
@@ -1095,29 +1163,38 @@ void graph( char *record)
     for (nr=0; nr<anz_lc; nr++)
     {
       sprintf(buffer, "%s.out", amplitude[dsNr[nr]].name);
-      if((dataset[0]=='l')&&(nr)) fprintf(handle_gnu, ", \"%s\" using 2:3 title '%s' with linespoints\\\n", buffer, amplitude[dsNr[nr]].name);
-      else if(dataset[0]=='l') fprintf(handle_gnu, "plot \"%s\" using 2:3 title '%s' with linespoints\\\n", buffer, amplitude[dsNr[nr]].name);
-      else fprintf(handle_gnu, "plot \"%s\" using 2:3 title '%s' with linespoints\n", buffer, amplitude[dsNr[nr]].name);
+      if(nr) fprintf(handle_gnu, ", \"%s\" using 2:3 title '%s' with linespoints pt %d\\\n", buffer, amplitude[dsNr[nr]].name, nr+1);
+      else fprintf(handle_gnu, "plot \"%s\" using 2:3 title '%s' with linespoints pt %d\\\n", buffer, amplitude[dsNr[nr]].name, nr+1);
     }
-    if(dataset[0]=='l') fprintf(handle_gnu, "\n");
+    if(nr) fprintf(handle_gnu, "\n");
     fclose(handle_gnu);
 
+    if((viewformat[0]=='p')&&(viewformat[1]=='n'))
+    {
+      sprintf(buffer, "amplitude.png");
+      printf ("write %s \n", buffer);
+      sprintf(buffer, "gnuplot amplitude.gnu" );
+      system (buffer);
 #ifdef WIN32
-    sprintf(buffer, "amplitude.png");
-    printf ("write %s \n", buffer);
-    sprintf(buffer, "gnuplot amplitude.gnu" );
-    system (buffer);
-//   if(inpformat)  sprintf(buffer, "%s amplitude.png &", psviewer );
-    if(inpformat) sprintf(buffer, "amplitude.png &");
-    system (buffer);
+      //if((inpformat)&&(graph_on))   sprintf(buffer, "%s amplitude.png &", psviewer );
+      if((inpformat)&&(graph_on))  sprintf(buffer, "amplitude.png &");
+      system (buffer);
 #else
-    sprintf(buffer, "amplitude.ps");
-    printf ("write %s \n", buffer);
-    sprintf(buffer, "gnuplot amplitude.gnu" );
-    system (buffer);
-    if(inpformat) sprintf(buffer, "%s amplitude.ps &", psviewer );
-    system (buffer);
+      if((inpformat)&&(graph_on))   sprintf(buffer, "%s amplitude.png &", psviewer );
+      system (buffer);
 #endif
+    }
+    else if((viewformat[0]=='p')&&(viewformat[1]=='s'))
+    {  
+      sprintf(buffer, "amplitude.ps");
+      printf ("write %s \n", buffer);
+      sprintf(buffer, "gnuplot amplitude.gnu" );
+      system (buffer);
+      if((inpformat)&&(graph_on))  sprintf(buffer, "%s amplitude.ps &", psviewer );
+      system (buffer);
+    }
+    else printf(" ERROR: Format not known:%s please set either ps or png with 'asgn viewformat'\n",viewformat);
+
     free(dsNr);
   } 
 
@@ -1145,7 +1222,7 @@ void graph( char *record)
       {
         sprintf(buffer, "%s_elastic.out",material[nr].name);
         handle_out = fopen (buffer, "w+b" );
-        if (handle_out==NULL) { printf ("\nThe output file \"%s\" could not be opened.\n\n", buffer); return;}
+        if (handle_out==NULL) { printf ("\nThe output file \"%s\" could not be opened.\n\n", buffer); return(-1);}
         for (i=0; i<material[indx].nela; i++)
         {
           fprintf (handle_out, "%d %e %e %e\n", i+1,material[indx].ela[i],material[indx].nue[i], material[indx].tela[i]);
@@ -1157,7 +1234,7 @@ void graph( char *record)
       {
         sprintf(buffer, "%s_expansion.out",material[nr].name);
         handle_out = fopen (buffer, "w+b" );
-        if (handle_out==NULL) { printf ("\nThe output file \"%s\" could not be opened.\n\n", buffer); return;}
+        if (handle_out==NULL) { printf ("\nThe output file \"%s\" could not be opened.\n\n", buffer); return(-1);}
         for (i=0; i<material[indx].nexp; i++)
         {
           fprintf (handle_out, "%d %e %e\n", i+1,material[indx].exp[i],material[indx].texp[i]);
@@ -1169,7 +1246,7 @@ void graph( char *record)
       {
         sprintf(buffer, "%s_conductivity.out",material[nr].name);
         handle_out = fopen (buffer, "w+b" );
-        if (handle_out==NULL) { printf ("\nThe output file \"%s\" could not be opened.\n\n", buffer); return;}
+        if (handle_out==NULL) { printf ("\nThe output file \"%s\" could not be opened.\n\n", buffer); return(-1);}
         for (i=0; i<material[indx].ncon; i++)
         {
           fprintf (handle_out, "%d %e %e\n", i+1,material[indx].con[i],material[indx].tcon[i]);
@@ -1181,13 +1258,28 @@ void graph( char *record)
       {
         sprintf(buffer, "%s_spec_heat.out",material[nr].name);
         handle_out = fopen (buffer, "w+b" );
-        if (handle_out==NULL) { printf ("\nThe output file \"%s\" could not be opened.\n\n", buffer); return;}
+        if (handle_out==NULL) { printf ("\nThe output file \"%s\" could not be opened.\n\n", buffer); return(-1);}
         for (i=0; i<material[indx].nsph; i++)
         {
           fprintf (handle_out, "%d %e %e\n", i+1,material[indx].sph[i],material[indx].tsph[i]);
         }
         fclose(handle_out);
       }
+
+      if(material[indx].npl)
+      {
+        sprintf(buffer, "%s_plastic.out",material[nr].name);
+        handle_out = fopen (buffer, "w+b" );
+        if (handle_out==NULL) { printf ("\nThe output file \"%s\" could not be opened.\n\n", buffer); return(-1);}
+	buf=material[indx].tpl[0];
+        for (i=0; i<material[indx].npl; i++)
+        {
+	  if(buf!= material[indx].tpl[i]) fprintf (handle_out, "\n\n");
+          fprintf (handle_out, "%d %e %e %e\n", i+1,material[indx].spl[i],material[indx].epl[i], material[indx].tpl[i]);
+	  buf=material[indx].tpl[i];
+        }
+        fclose(handle_out);
+      }
       if((dsNr=(int *)realloc((int *)dsNr, (anz_lc+1) *sizeof(int)))==NULL )
         printf("\n\n ERROR: malloc failed \n\n") ;
       dsNr[anz_lc]=nr;
@@ -1196,17 +1288,22 @@ void graph( char *record)
 
     sprintf(buffer, "material.gnu");
     handle_gnu = fopen (buffer, "w+b" );
-    if (handle_gnu==NULL) { printf ("\nThe output file \"%s\" could not be opened.\n\n",buffer); return;}
-#ifdef WIN32
-    fprintf(handle_gnu, "set term png\n");
-    sprintf(buffer, "material.png", graph_Nr);
-    fprintf(handle_gnu, "set out \"%s\"\n", buffer);
-#else
-    fprintf(handle_gnu, "set term postscript landscape monochrom  \n");
-    fprintf(handle_gnu, "#set term x11 \n");
-    sprintf(buffer, "material.ps");
-    fprintf(handle_gnu, "set out \"%s\"\n", buffer);
-#endif
+    if (handle_gnu==NULL) { printf ("\nThe output file \"%s\" could not be opened.\n\n",buffer); return(-1);}
+    if((viewformat[0]=='p')&&(viewformat[1]=='n'))
+    {
+      fprintf(handle_gnu, "set term png\n");
+      sprintf(buffer, "material.png");
+      fprintf(handle_gnu, "set out \"%s\"\n", buffer);
+    }
+    else if((viewformat[0]=='p')&&(viewformat[1]=='s'))
+    {
+      fprintf(handle_gnu, "set term postscript landscape monochrom noenhanced \n");
+      fprintf(handle_gnu, "#set term x11 \n");
+      sprintf(buffer, "material.ps");
+      fprintf(handle_gnu, "set out \"%s\"\n", buffer);
+    }
+    else printf(" ERROR: Format not known:%s please set either ps or png with 'asgn viewformat'\n",viewformat);
+
     fprintf(handle_gnu, "set grid\n");
     fprintf(handle_gnu, "set title \"Material\"\n");
 
@@ -1218,13 +1315,12 @@ void graph( char *record)
       if(material[dsNr[nr]].nela)
       {
         sprintf(buffer, "%s_elastic.out", material[dsNr[nr]].name);
-        if((dataset[0]=='l')&&(sum)) fprintf(handle_gnu, ", \"%s\" using 4:2 title '%s' with linespoints\\\n", buffer, material[dsNr[nr]].name);
-        else if(dataset[0]=='l') fprintf(handle_gnu, "plot \"%s\" using 4:2 title '%s' with linespoints\\\n", buffer, material[dsNr[nr]].name);
-        else fprintf(handle_gnu, "plot \"%s\" using 4:2 title '%s' with linespoints\n", buffer, material[dsNr[nr]].name);
+        if(sum) fprintf(handle_gnu, ", \"%s\" using 4:2 title '%s' with linespoints\\\n", buffer, material[dsNr[nr]].name);
+        else fprintf(handle_gnu, "plot \"%s\" using 4:2 title '%s' with linespoints\\\n", buffer, material[dsNr[nr]].name);
         sum++;
       }
     }
-    if((sum)&&(dataset[0]=='l')) fprintf(handle_gnu, "\n");
+    if(sum) fprintf(handle_gnu, "\n");
 
     fprintf(handle_gnu, "set ylabel \" Expansion Coefficient \"\n");
     fprintf(handle_gnu, "set xlabel \" Temperature \"\n");
@@ -1234,13 +1330,12 @@ void graph( char *record)
       if(material[dsNr[nr]].nexp)
       {
         sprintf(buffer, "%s_expansion.out", material[dsNr[nr]].name);
-        if((dataset[0]=='l')&&(sum)) fprintf(handle_gnu, ", \"%s\" using 3:2 title '%s' with linespoints\\\n", buffer, material[dsNr[nr]].name);
-        else if(dataset[0]=='l') fprintf(handle_gnu, "plot \"%s\" using 3:2 title '%s' with linespoints\\\n", buffer, material[dsNr[nr]].name);
-        else fprintf(handle_gnu, "plot \"%s\" using 3:2 title '%s' with linespoints\n", buffer, material[dsNr[nr]].name);
+        if(sum) fprintf(handle_gnu, ", \"%s\" using 3:2 title '%s' with linespoints\\\n", buffer, material[dsNr[nr]].name);
+        else fprintf(handle_gnu, "plot \"%s\" using 3:2 title '%s' with linespoints\\\n", buffer, material[dsNr[nr]].name);
         sum++;
       }
     }
-    if((sum)&&(dataset[0]=='l')) fprintf(handle_gnu, "\n");
+    if(sum) fprintf(handle_gnu, "\n");
 
     fprintf(handle_gnu, "set ylabel \" Conductivity \"\n");
     fprintf(handle_gnu, "set xlabel \" Temperature \"\n");
@@ -1250,13 +1345,12 @@ void graph( char *record)
       if(material[dsNr[nr]].ncon)
       {
         sprintf(buffer, "%s_conductivity.out", material[dsNr[nr]].name);
-        if((dataset[0]=='l')&&(sum)) fprintf(handle_gnu, ", \"%s\" using 3:2 title '%s' with linespoints\\\n", buffer, material[dsNr[nr]].name);
-        else if(dataset[0]=='l') fprintf(handle_gnu, "plot \"%s\" using 3:2 title '%s' with linespoints\\\n", buffer, material[dsNr[nr]].name);
-        else fprintf(handle_gnu, "plot \"%s\" using 3:2 title '%s' with linespoints\n", buffer, material[dsNr[nr]].name);
+        if(sum) fprintf(handle_gnu, ", \"%s\" using 3:2 title '%s' with linespoints\\\n", buffer, material[dsNr[nr]].name);
+        else fprintf(handle_gnu, "plot \"%s\" using 3:2 title '%s' with linespoints\\\n", buffer, material[dsNr[nr]].name);
         sum++;
       }
     }
-    if((sum)&&(dataset[0]=='l')) fprintf(handle_gnu, "\n");
+    if(sum) fprintf(handle_gnu, "\n");
 
     fprintf(handle_gnu, "set ylabel \" Specific Heat \"\n");
     fprintf(handle_gnu, "set xlabel \" Temperature \"\n");
@@ -1266,31 +1360,65 @@ void graph( char *record)
       if(material[dsNr[nr]].nsph)
       {
         sprintf(buffer, "%s_spec_heat.out", material[dsNr[nr]].name);
-        if((dataset[0]=='l')&&(sum)) fprintf(handle_gnu, ", \"%s\" using 3:2 title '%s' with linespoints\\\n", buffer, material[dsNr[nr]].name);
-        else if(dataset[0]=='l') fprintf(handle_gnu, "plot \"%s\" using 3:2 title '%s' with linespoints\\\n", buffer, material[dsNr[nr]].name);
-        else fprintf(handle_gnu, "plot \"%s\" using 3:2 title '%s' with linespoints\n", buffer, material[dsNr[nr]].name);
+        if(sum) fprintf(handle_gnu, ", \"%s\" using 3:2 title '%s' with linespoints\\\n", buffer, material[dsNr[nr]].name);
+        else fprintf(handle_gnu, "plot \"%s\" using 3:2 title '%s' with linespoints\\\n", buffer, material[dsNr[nr]].name);
         sum++;
       }
     }
-    if((sum)&&(dataset[0]=='l')) fprintf(handle_gnu, "\n");
+    if(sum) fprintf(handle_gnu, "\n");
+
+    fprintf(handle_gnu, "set ylabel \" Stress \"\n");
+    fprintf(handle_gnu, "set xlabel \" Plastic Strain \"\n");
+    for (nr=0; nr<anz_lc; nr++)
+    {
+      if(material[dsNr[nr]].npl)
+      {
+        sprintf(buffer, "%s_plastic.out", material[dsNr[nr]].name);
+        fprintf(handle_gnu, "set title \"%s\"\n", material[dsNr[nr]].name);
+	buf=-1.;
+        sum=0;
+        for (i=0; i<material[dsNr[nr]].npl; i++)
+        {
+	  // new temps
+	  if(buf!= material[dsNr[nr]].tpl[i])
+	  {
+            buf=material[dsNr[nr]].tpl[i];
+            if(sum) fprintf(handle_gnu, ", \"%s\" index %d using 3:2 title '%s T:%.1f' with linespoints\\\n", buffer, sum, material[dsNr[nr]].name, buf);
+	    else fprintf(handle_gnu, "plot \"%s\" index %d using 3:2 title '%s T:%.1f' with linespoints\\\n", buffer, sum, material[dsNr[nr]].name, buf);
+            sum++;
+	  }
+	}
+        if(sum) fprintf(handle_gnu, "\n");
+      }
+    }
     fclose(handle_gnu);
 
+    if((viewformat[0]=='p')&&(viewformat[1]=='n'))
+    {
+      sprintf(buffer, "material.png");
+      printf ("write %s \n", buffer);
+      sprintf(buffer, "gnuplot material.gnu" );
+      system (buffer);
 #ifdef WIN32
-    sprintf(buffer, "material.png");
-    printf ("write %s \n", buffer);
-    sprintf(buffer, "gnuplot material.gnu" );
-    system (buffer);
-//   if(inpformat)  sprintf(buffer, "%s material.png &", psviewer );
-    if(inpformat) sprintf(buffer, "material.png &");
-    system (buffer);
+      //if((inpformat)&&(graph_on))   sprintf(buffer, "%s material.png &", psviewer );
+      if((inpformat)&&(graph_on))  sprintf(buffer, "material.png &");
+      system (buffer);
 #else
-    sprintf(buffer, "material.ps");
-    printf ("write %s \n", buffer);
-    sprintf(buffer, "gnuplot material.gnu" );
-    system (buffer);
-    if(inpformat) sprintf(buffer, "%s material.ps &", psviewer );
-    system (buffer);
+      if((inpformat)&&(graph_on))   sprintf(buffer, "%s material.png &", psviewer );
+      system (buffer);
 #endif
+    }
+    else if((viewformat[0]=='p')&&(viewformat[1]=='s'))
+    {  
+      sprintf(buffer, "material.ps");
+      printf ("write %s \n", buffer);
+      sprintf(buffer, "gnuplot material.gnu" );
+      system (buffer);
+      if((inpformat)&&(graph_on))  sprintf(buffer, "%s material.ps &", psviewer );
+      system (buffer);
+    }
+    else printf(" ERROR: Format not known:%s please set either ps or png with 'asgn viewformat'\n",viewformat);
+
     free(dsNr);
   } 
   else
@@ -1314,7 +1442,7 @@ void graph( char *record)
       if(!anz_lc)
       {
         printf(" ERROR: found no matching Dataset for string:%s\n", dataset);
-        return;
+        return(-1);
       }
       dsNr[0]=anz_lc;
 
@@ -1330,7 +1458,7 @@ void graph( char *record)
           if( pre_readfrdblock(copiedNodeSets , dsNr[1], anz, node, lcase )==-1) 
           {
             printf("ERROR in graph: Could not read data for Dataset:%d\n", dsNr[1]+1); 
-            return;
+            return(-1);
           }
           calcDatasets( dsNr[1], anz, node, lcase );
           recompileEntitiesInMenu(dsNr[1]);
@@ -1348,7 +1476,7 @@ void graph( char *record)
        if(eNr==-1)
        {
         printf(" ERROR: found no matching entity for string:%s\n", entity);
-        return;
+        return(-1);
        }
       }
     }
@@ -1358,7 +1486,7 @@ void graph( char *record)
       if (dsSequence.nds<1)
       {
         errMsg(" ERROR: no sequence is defined, choose the menu-entry \"Animate->Toggle Dataset Sequence\" and define a sequence\n\n");
-        return;
+        return(-1);
       }
       anz_lc=0;
       for(i=0; i<dsSequence.nds; i++)
@@ -1384,10 +1512,11 @@ void graph( char *record)
       if (indx<0)
       {
         errMsg(" ERROR: Set (%s) is undefined", name );
-        return;
+        return(-1);
       }
       plot2D( type, indx, dsNr, eNr);
     }
     free(dsNr);
   } 
+  return(graph_Nr);
 }
