@@ -1585,6 +1585,8 @@ double intpol3(double *x, double *y, int n, double x0, int *method, double s, in
 
   /* Daten nach aufsteigendem x sortieren */
 
+  if(n==1) return(y[0]);
+  
   if((xsort =(double *)malloc((int)(n+1) *sizeof(double)))==NULL)
   {  printf("\n\n ERROR in intpol3: malloc xsort failed \n\n") ; }
   if((ysort =(double *)malloc((int)(n+1) *sizeof(double)))==NULL)
@@ -1600,7 +1602,12 @@ double intpol3(double *x, double *y, int n, double x0, int *method, double s, in
     xsort[j]=x[isort[imax-j]];
     ysort[j]=y[isort[imax-j]];
   }
-
+  /*
+  for(j=0; j<n; j++)
+  {
+    printf("xsort:%f ysort:%f\n",xsort[j], ysort[j]);
+  }
+  */
   if ((x0 < xsort[0])||(x0 > xsort[n-1])) *method=0;
   if ((*method==0)||(n<3))       /* lineare interpolation */
   {
