@@ -12,7 +12,7 @@ int iremove(int **ipnt, int n, int x0 )
     printf("a:%d\n", *ipnt); 
 #endif
 
-  if(n==0) return(n);
+  if(n<=0) return(n);
   x=*ipnt;
 
   /* return if x0 is lower than the first elem or if x0 is higher than the last elem */
