@@ -1192,8 +1192,7 @@ pnt_v: v
 OUT:
 pnt_u: u (of all nodes)
 pnt_v: v
-apre: no of nodes and elements
-epre: elements (tr3)
+pnt_flag=1: boundary node
 return: number of tri3 or 0 if in error, -1 if the distance between points is 0.
  */
 
@@ -1222,6 +1221,14 @@ int mesh2d(int *_nt, int _nb, int *npc, double **_pnt_u, double **_pnt_v, int **
   GlobalVariables *gv;
   int pivot=1;
 
+  int e,k,l,m;
+  int ntbuf, *pnt_flag_buf;
+  typedef struct{
+    int valid;
+    int n[3];
+  }Tribuf;
+  Tribuf   *tribuf, *trinew=NULL;
+
   /* initialize all global variables */
   if( (gv = (GlobalVariables *)calloc( (1),sizeof(GlobalVariables) )) == NULL )
   { printf(" ERROR: malloc failure in mesh2d()\n\n");      return(0); }
@@ -1246,7 +1253,7 @@ int mesh2d(int *_nt, int _nb, int *npc, double **_pnt_u, double **_pnt_v, int **
   tri3=*_tri3;
 
   /* store in global mesh2d variables */
-  gv->NT=*_nt;
+  gv->NT=ntbuf=*_nt;
   gv->NB=_nb;
   if(gv->NB>=BOUNDLOOPS) { printf(" ERROR: Increase BOUNDLOOPS in mesh2d to more than:%d\n",gv->NB); return(0); }
 
@@ -1443,6 +1450,136 @@ int mesh2d(int *_nt, int _nb, int *npc, double **_pnt_u, double **_pnt_v, int **
       tri3[n++]=gv->tc[i].n[3];
     }
   }
+
+  // NEW: remove unwanted tri3
+
+  // combine tri which use an not permitted newly created boundary node
+  if( (pnt_flag_buf = (int *)calloc( (gv->NP+1), sizeof(int) )) == NULL )
+  { printf(" ERROR: calloc failure in mesh2d()\n\n");
+    return(0); }
+  for(i=0; i<gv->NP; i++)
+  {
+    pnt_flag_buf[i]=pnt_flag[i];
+  }
+  for(i=4; i<ntbuf+4; i++)
+  {
+    //printf("%d uv: %f %f\n",i,pnt_u[i],pnt_v[i]);
+    pnt_flag_buf[i]=0;
+  }
+  for(i=0; i<gv->NP; i++)
+  {
+    if(pnt_flag_buf[i]==1) break;
+  }
+
+  if(i<gv->NP)
+  {
+    printf(" mesh2d: ignore new boundary nodes\n");
+    
+    if( (tribuf = (Tribuf *)malloc( (n/3)*sizeof(Tribuf) )) == NULL )
+    { printf(" ERROR: malloc failure in mesh2d()\n\n");
+      return(0); }
+    if( (trinew = (Tribuf *)calloc((gv->NP+1), sizeof(Tribuf) )) == NULL )
+    { printf(" ERROR: caalloc failure in mesh2d()\n\n");
+      return(0); }
+  
+    // generate preliminary tri elements
+    j=0;
+    for(e=0; e<n/3; e++)
+    {
+      for(i=0; i<3; i++)
+      {
+        tribuf[e].valid=1;
+        tribuf[e].n[i]=tri3[j+i];
+        //printf(" tribuf[%d].n[%d]=tri3[%d]-1 = n:%d uv:%f %f\n", e,i,j+i, tri3[j+i]-1, pnt_u[tribuf[e].n[i]-1],pnt_v[tribuf[e].n[i]-1]);
+      }
+      j+=3;
+    }
+    for(i=0; i<gv->NP; i++)
+    {
+      if(pnt_flag_buf[i]==1)
+      {
+        //printf("eliminate i:%d uv: %f %f\n",i,pnt_u[i],pnt_v[i]);
+        // go over all tri and search for that node
+        /*
+        for(j=0; j<n; j++)
+        {
+  	if((tri3[j]-1)==i) printf("found  tri3[%d]-1:%d == i:%d uv:%f %f\n", j,tri3[j]-1,i, pnt_u[tri3[j]-1],pnt_v[tri3[j]-1]);
+  	else  printf("tri3[%d]-1:%d == i:%d uv:%f %f\n", j,tri3[j]-1, i, pnt_u[tri3[j]-1],pnt_v[tri3[j]-1]);
+  
+        }
+        */
+        // go over all tribuf and search for that node
+        for(e=0; e<n/3; e++)
+        {
+          for(k=0; k<3; k++)
+          {
+  	  if((tribuf[e].n[k]-1)==i)
+  	  {
+              tribuf[e].valid=0;
+  	    //printf("found i in e:%d\n",e);
+  	    if(!trinew[i].valid)
+  	    {
+  	      for(l=0; l<3; l++) trinew[i].n[l]=tribuf[e].n[l];
+                trinew[i].valid=1;
+  	    }
+  	    else
+  	    {
+  	      for(l=0; l<3; l++)
+  	      {
+  		if((trinew[i].n[l]-1)==i) break;
+  	      }
+  	      // found l to be used
+  	      for(m=0; m<3; m++)
+  	      {
+  		if((tribuf[e].n[m]!=trinew[i].n[0])&&(tribuf[e].n[m]!=trinew[i].n[1])&&(tribuf[e].n[m]!=trinew[i].n[2])) break;
+  	      }
+  	      trinew[i].n[l]=tribuf[e].n[m];
+  	      //for(l=0; l<3; l++) printf(" trinew[%d].n[%d]  uv:%f %f\n", i,l, pnt_u[trinew[i].n[l]-1],pnt_v[trinew[i].n[l]-1]);
+  	    }
+            }
+          }
+        }
+      }
+    }
+    
+    // update tri structure
+    j=0;
+    for(e=0; e<n/3; e++)
+    {
+      if(tribuf[e].valid)
+      {
+        for(i=0; i<3; i++)
+        {
+  	tri3[j+i]=tribuf[e].n[i];
+        }
+        j+=3;
+      }
+    }
+    //printf("j:%d n:%d\n",j,n);
+  
+    // add new elements
+    for(i=0; i<gv->NP; i++)
+    {
+      if(trinew[i].valid)
+      {
+        for(l=0; l<3; l++)
+        {
+          // printf(" trinew[%d].n[%d]  uv:%f %f\n", i,l, pnt_u[trinew[i].n[l]-1],pnt_v[trinew[i].n[l]-1]);
+  	tri3[j+l]=trinew[i].n[l];
+        }
+        j+=3;
+      }
+    }
+    //printf("j:%d n:%d\n",j,n);
+    n=j;
+    
+    free(tribuf);
+    free(trinew);
+  }
+  free(pnt_flag_buf);
+
+  // end NEW
+  
   *_nt=gv->NP;
   *_pnt_u=pnt_u;
   *_pnt_v=pnt_v;
