@@ -120,7 +120,7 @@ int orientLcmb( int nr )
   }
   if (i==lcmb[nr].nl)
   {
-    errMsg(" ERROR: lcmb %s are a closed loop, no orientation possible\n", lcmb[nr].name);
+    errMsg(" ERROR: lcmb %s is a closed loop, no orientation possible\n", lcmb[nr].name);
     for (j=0; j<lcmb[nr].nl; j++) printf(" %s", line[lcmb[nr].l[j]].name);
     printf("\n");
     err=-i;
@@ -200,16 +200,23 @@ int orientLcmb( int nr )
 /* vorher ist ein tet-volumen netz nicht erzeugbar */
 int orientSurf( int nr )
 {
+#define TEST 0
   int i,j=0, n=0;
-  int     flag1, flag2, err=0, lcount=0;
+  int     flag1, flag2, err=0, lcount=0, lastlcount, closedLoopFlag;
   int     p1,p2, pnt=0, sl, cl, l0;
   int     line0_p1, line0_p2;
   int     *sortLines=NULL;
   int     *cp=NULL;
   char    *sortOri=NULL, *tmpOri=NULL, *sortTyp=NULL;
 
-
-  if(printFlag) printf (" orient surf:%s ", surf[nr].name);
+  if(surf[nr].nl<1) return(-1);
+  if(printFlag) printf (" orient surf:%s \n", surf[nr].name);
+#if TEST    
+  printf (" orient surf:%s nl:%d\n", surf[nr].name, surf[nr].nl);
+    for(i=0; i<surf[nr].nl; i++)
+      printf ("  surf[nr].o[i]:%c surf[nr].typ[n]:%c surf[nr].l[n]:%d\n", surf[nr].o[i],surf[nr].typ[n],surf[nr].l[n]);
+     
+#endif
 
   if((sortOri = (char *)realloc((char *)sortOri, (surf[nr].nl)*sizeof(char)) ) == NULL )
   { printf(" ERROR: realloc failure in orientSurf()\n\n"); return(-1); }
@@ -232,12 +239,13 @@ int orientSurf( int nr )
 
 
   /* Definiere die Linienzuege (curves) zb: Auessere Umrandung, innere Loecher */
-  /* die einzelnen Linenzuege werden zum NURBS-Trimming benutzt. Zumstrukturierten Vernetzen sind */
+  /* die einzelnen Linenzuege werden zum NURBS-Trimming benutzt. Zum strukturierten Vernetzen sind */
   /* nur Surfaces mit einem Linienzug geeignet */
   do
   {
+    lastlcount=lcount;
 #if TEST    
-    printf("curve starts with n:%d lcount:%d \n",n,lcount);
+    printf("\n curve starts with n:%d lcount:%d \n",n,lcount);
 #endif
     /* suche den punkt einer linie die mit der ersten linie verbunden ist */
     /* und orientiere die erste linie */
@@ -260,7 +268,7 @@ int orientSurf( int nr )
     }
   
 #if TEST    
-    for (i=0; i<surf[nr].nl; i++)
+    for (i=n; i<surf[nr].nl; i++)
     {
       if (surf[nr].typ[i]=='c')
         printf("%1c %1c %s\n",surf[nr].typ[i], surf[nr].o[i], lcmb[surf[nr].l[i]].name);
@@ -296,7 +304,7 @@ int orientSurf( int nr )
         p1=line[surf[nr].l[i]].p1;
         p2=line[surf[nr].l[i]].p2;
 #if TEST    
-    printf ("l:%s  \n", line[surf[nr].l[i]].name );
+    printf ("l:%s  p1:%s p2:%s  \n", line[surf[nr].l[i]].name, point[p1].name, point[p2].name );
 #endif
       }
   
@@ -348,12 +356,20 @@ int orientSurf( int nr )
 
     if (i==surf[nr].nl)
     {
-      errMsg("WARNING: surf not closed, no orientation possible\n");
-      for (i=0; i<surf[nr].nl; i++)
+      if(surf[nr].typ[n]=='l') errMsg("WARNING: line[%d]:%s not connected\n",n,line[surf[nr].l[n]].name);
+      //surf[nr].typ[n]='d';
+      if(surf[nr].typ[n]=='l')  surf[nr].typ[n]='L'; else surf[nr].typ[n]='C';
+      n++;
+      if(n==surf[nr].nl)
       {
-        surf[nr].o[i]='+';
+        errMsg("WARNING: surf not closed, no orientation possible\n");
+        for (i=0; i<surf[nr].nl; i++)
+        {
+          surf[nr].o[i]='+';
+        }
+        goto orientSurfError;
       }
-      goto orientSurfError;
+      else continue;
     }
     else
     {
@@ -368,16 +384,18 @@ int orientSurf( int nr )
     }
 
 #if TEST    
-   printf ("Curve:%d Start-line:%s ori:%c 2line:%s ori:%c \n",surf[nr].nc,line[surf[nr].l[n]].name, surf[nr].o[n], line[surf[nr].l[i]].name, surf[nr].o[i] );
+    printf ("Curve:%d Start-line:%s ori:%c 2line:%s ori:%c \n",surf[nr].nc,line[surf[nr].l[n]].name, surf[nr].o[n], line[surf[nr].l[i]].name, surf[nr].o[i] );
 #endif
-    for (i=n+1; i<surf[nr].nl; i++)  /* ori die restlichen linien */
+    
+    closedLoopFlag=0;
+    for (i=0; i<surf[nr].nl; i++) /* suche die anschliessende durch vergleich (with inner second loop!)*/
     {
-      for (j=0; j<surf[nr].nl; j++) /* suche die anschliessende durch vergleich */
+      for (j=n+1; j<surf[nr].nl; j++) /* suche die anschliessende durch vergleich */
       {
         if (!surf[nr].o[j])              /* wenn ori noch == 0 */
         {
 #if TEST    
-          printf ("pnt:%s nr:%d j:%d\n", point[pnt].name, nr,j);
+          printf ("check pnt:%s pnt:%d j:%d\n", point[pnt].name, pnt, j);
 #endif
           if (surf[nr].typ[j]=='c')
           {
@@ -388,7 +406,7 @@ int orientSurf( int nr )
             if(lcmb[sl].o[cl]=='+')   p2=line[lcmb[sl].l[cl]].p2;
             else                      p2=line[lcmb[sl].l[cl]].p1;
 #if TEST    
-   printf ("lcmb:%s pnt:%d p1:%d p2:%d\n", lcmb[surf[nr].l[j]].name, pnt, p1, p2 );
+          printf ("compare i:%d j:%d lcmb:%s pnt:%d p1:%d p2:%d\n", i,j, lcmb[surf[nr].l[j]].name, pnt, p1, p2 );
 #endif
           }
           else
@@ -396,72 +414,99 @@ int orientSurf( int nr )
             p1=line[surf[nr].l[j]].p1;
             p2=line[surf[nr].l[j]].p2;
 #if TEST    
-   printf ("i:%d j:%d line:%s ori:%c pnt:%d p1:%d p2:%d\n", i,j,line[surf[nr].l[j]].name, surf[nr].o[j], pnt, p1, p2 );
+          printf ("compare i:%d j:%d line:%s ori:%c pnt:%d p1:%d p2:%d\n", i,j, surf[nr].o[j], pnt, p1, p2 );
 #endif
           }
-  
+
           if ( p1 == pnt )
-          {  pnt=p2; surf[nr].o[j]='+';
+          {
+	    pnt=p2; surf[nr].o[j]='+';
 #if TEST    
-   printf ("i:%d j:%d line:%s pnt:%d p1:%d p2:%d\n", i,j,line[surf[nr].l[j]].name, pnt, p1, p2 );
+          printf ("found i:%d j:%d p1:%d p2:%d  next pnt:%d\n", i,j, p1, p2, pnt );
 #endif
-             sortLines[lcount]=surf[nr].l[j]; sortOri[lcount]=surf[nr].o[j];
-             sortTyp[lcount]=surf[nr].typ[j]; lcount++; }
+            sortLines[lcount]=surf[nr].l[j]; sortOri[lcount]=surf[nr].o[j];
+            sortTyp[lcount]=surf[nr].typ[j]; lcount++;
+          }
           else if ( p2 ==  pnt )
-          {  pnt=p1; surf[nr].o[j]='-';
+          {
+	    pnt=p1; surf[nr].o[j]='-';
 #if TEST    
-   printf ("i:%d j:%d line:%s pnt:%d p1:%d p2:%d\n", i,j,line[surf[nr].l[j]].name, pnt, p1, p2 );
+          printf ("found i:%d j:%d  p1:%d p2:%d  next pnt:%d\n", i,j, p1, p2, pnt );
 #endif
-             sortLines[lcount]=surf[nr].l[j]; sortOri[lcount]=surf[nr].o[j];
-             sortTyp[lcount]=surf[nr].typ[j]; lcount++; }
+            sortLines[lcount]=surf[nr].l[j]; sortOri[lcount]=surf[nr].o[j];
+            sortTyp[lcount]=surf[nr].typ[j]; lcount++;
+          }
         }
       }
-    }
 
-    /* check if the curve is closed and store the first line-index of the surf */
-    if(sortTyp[n]=='l')
-    {
-      if((pnt==line[sortLines[n]].p1)||(pnt==line[sortLines[n]].p2))
-      {
-        /* start-index of the curve */
-        if((surf[nr].c=(int *)realloc((int *)surf[nr].c, (surf[nr].nc+1)*sizeof(int)) )==NULL)
-        { printf(" ERROR: realloc failure in orient surf:%s can not be oriented\n", surf[nr].name); exit(-1); }
-        surf[nr].c[surf[nr].nc]=lcount-n;
-        surf[nr].nc++;
-      }
-    }
-    else if(sortTyp[n]=='c')
-    {
-      if((pnt==lcmb[sortLines[n]].p1)||(pnt==lcmb[sortLines[n]].p2))
-      {
-        /* start-index of the curve */
-        if((surf[nr].c=(int *)realloc((int *)surf[nr].c, (surf[nr].nc+1)*sizeof(int)) )==NULL)
-        { printf(" ERROR: realloc failure in orient surf:%s can not be oriented\n", surf[nr].name); exit(-1); }
-        surf[nr].c[surf[nr].nc]=lcount-n;
-        surf[nr].nc++;
-      }
-    }
-    else
-    {
-      printf("WARNING in ori: Surf:%s has an unclosed curve\n", surf[nr].name);
-      printf("typ:%c pnt:%s line[sortLines[n]].p1:%s line[sortLines[n]].p2:%s\n", sortTyp[n], point[pnt].name, point[line[sortLines[n]].p1].name, point[line[sortLines[n]].p2].name);
-      goto finish_ori;
-    }
+#if TEST    
+      printf ("check connected lines\n");
+#endif
 
+      /* check if the curve is closed  */
+      if(surf[nr].typ[n]=='l')
+      {
+        if((pnt==line[surf[nr].l[n]].p1)||(pnt==line[surf[nr].l[n]].p2))
+        {
+          /* number of lines in each curve */
+          if((surf[nr].c=(int *)realloc((int *)surf[nr].c, (surf[nr].nc+1)*sizeof(int)) )==NULL)
+          { printf(" ERROR: realloc failure in orient surf:%s can not be oriented\n", surf[nr].name); exit(-1); }
+          surf[nr].c[surf[nr].nc]=lcount-lastlcount;
+          surf[nr].nc++;
+	  closedLoopFlag=1;
+#if TEST    
+          printf ("line, closed line loop found, n:%d\n",n);
+#endif
+        }
+      }
+      else if(surf[nr].typ[n]=='c')
+      {
+        if((pnt==lcmb[surf[nr].l[n]].p1)||(pnt==lcmb[surf[nr].l[n]].p2))
+        {
+          /* number of lines in each curve */
+          if((surf[nr].c=(int *)realloc((int *)surf[nr].c, (surf[nr].nc+1)*sizeof(int)) )==NULL)
+          { printf(" ERROR: realloc failure in orient surf:%s can not be oriented\n", surf[nr].name); exit(-1); }
+          surf[nr].c[surf[nr].nc]=lcount-lastlcount;
+          surf[nr].nc++;
+	  closedLoopFlag=1;
+#if TEST    
+          printf ("lcmb, closed line loop found, n:%d\n",n);
+#endif
+        }
+      }
+      if(closedLoopFlag==1) break;
+    }
+    if(closedLoopFlag==0) lcount=lastlcount;
+
+    
     /* check for unoriented lines */
     err=0;
     for (n=0; n<surf[nr].nl; n++)
     {
-      if (!surf[nr].o[n])
-      {
+      //if( (!surf[nr].o[n])&&(surf[nr].typ[n]!='d'))
+       if( (!surf[nr].o[n]) && ((surf[nr].typ[n]!='L')&&(surf[nr].typ[n]!='C')) )
+       {
         err--;
         break;
       }
     }
   }while(err<0);
 
+#if TEST    
+  printf("lcount:%d surf[nr].nl:%d\n",lcount,surf[nr].nl);
+#endif
+
+  /* re-define surf[nr] here and erase the unconnected lines */
+  if(!lcount) goto orientSurfError;
+  for (n=0; n<lcount; n++)
+  {
+      surf[nr].typ[n]=sortTyp[n];
+      surf[nr].l[n]=sortLines[n];
+      surf[nr].o[n]=sortOri[n];
+  }
+  surf[nr].nl=lcount;
+  
 
-  finish_ori:;
   /* check of the loop was closed */
   if(surf[nr].nc==0)
   {
@@ -569,6 +614,8 @@ int orientSurf( int nr )
   surf[nr].cp=cp;
   for (i=0; i<surf[nr].nl; i++)
   {  
+    if(surf[nr].typ[i]=='L') surf[nr].typ[i]='l';
+    if(surf[nr].typ[i]=='C') surf[nr].typ[i]='c'; // back to original typ
     surf[nr].cx+=(point[cp[i]].px* scale->w+scale->x)/surf[nr].nl;
     surf[nr].cy+=(point[cp[i]].py* scale->w+scale->y)/surf[nr].nl;
     surf[nr].cz+=(point[cp[i]].pz* scale->w+scale->z)/surf[nr].nl;
@@ -578,13 +625,20 @@ int orientSurf( int nr )
   free(sortOri);
   free(tmpOri);
   free(sortTyp);
+  surf[nr].fail=0;
   return(err);
  orientSurfError:;
+  for (i=0; i<surf[nr].nl; i++)
+  {
+    if(surf[nr].typ[i]=='L')  surf[nr].typ[i]='l';
+    if(surf[nr].typ[i]=='C')  surf[nr].typ[i]='c'; // back to original typ
+  }
   free(sortLines);
   free(cp);
   free(sortOri);
   free(tmpOri);
   free(sortTyp);
+  surf[nr].fail=2 ;
   return(-1);
 }
 
@@ -1918,6 +1972,10 @@ int orientBody( int nr )
   for (i=0; i<body[nr].ns; i++)
   {
     s=body[nr].s[i];
+    if ( orientSurf( s ) <0 )
+    {
+      errMsg ("WARNING: orientSurf:%s failed\n", surf[s].name);
+    }
 
     /* suche den ersten punkt der ersten linie oder lcmb der surf */
     if(surf[s].nl<1)
