@@ -395,7 +395,8 @@ int readDuns(char *datin, Summen *anz, Nodes **nptr, Elements **eptr, Datasets *
             elem[anz->e].group= i;
             elem[anz->e].mat = 1;
             anz->etype[elem[anz->e].type]++;
-            elem[anz->e].nr  = ++anz->e;
+            anz->e++;
+            elem[anz->e-1].nr  = anz->e;
           }
         }
       }
@@ -478,7 +479,8 @@ int readDuns(char *datin, Summen *anz, Nodes **nptr, Elements **eptr, Datasets *
           elem[anz->e].group= i;
           elem[anz->e].mat = 1;
           anz->etype[elem[anz->e].type]++;
-          elem[anz->e].nr  = ++anz->e;
+          anz->e++;
+          elem[anz->e-1].nr  = anz->e;
         }
       }  
       anz->n+=nsz;
@@ -671,7 +673,7 @@ int readDuns(char *datin, Summen *anz, Nodes **nptr, Elements **eptr, Datasets *
       lcase[anz->l].value=ld100;
       lcase[anz->l].ncomps = nident;
       lcase[anz->l].irtype = 1;
-      sprintf( lcase[anz->l].name,"%s", datin);
+      sprintf( lcase[anz->l].name,"%s", "duns");
       printf ("lcase.name[%d]= %s\n", anz->l, lcase[anz->l].name);
 
       lcase[anz->l].npheader=0;
