@@ -617,7 +617,7 @@ int readFoam(char *datin, Summen *apre, Sets **sptr, Nodes **nptr, Elements **ep
         {
           printf("\n   setname:%s\n",  buffer);
           setNr=getSetNrx(buffer);
-          if(setNr<0) setNr=pre_setax( buffer, "is", 0);
+          if(setNr<0) setNr=pre_setax( buffer, "i", 0);
         }
         else sscanf(rec_str, "%s", buffer);
 
