@@ -7,6 +7,11 @@
 /* C are output in the function file. The turbulence quantities are output as   */
 /* C they are calculated and are not converted to 'conserved' form.             */
 /* ---------------------------------------------------------------------------  */
+/*
+This function uses the following empirical functions (si units)
+    wl=0.0245*(1.+0.00225*(temp-273.15));  // thermal conductivity
+    R_GAS  287.1
+*/
 
 
 #include <extUtil.h>
@@ -15,29 +20,25 @@
 #define MAXIDENTIFIER  12 
 #define MAXINTEGER 2147483647
 #define MAXFLOAT   1.e32
-#define MAX_BLOCKS  100000
+#define MAX_BLOCKS  1000
 
 
 
-#define kappa    1.4 /* in ISAAC defined */
 #define RHOINF 1.    /* in ISAAC defined */
-
 #define _R_GAS  287.1 /* real Gas-Constant */
-#define _PINF   1.e5; /* real ambient static pressure */
-#define _TINF   288.  /* real ambient static temperature */
 
-int calcAddEntitiesIsaac( Summen *anz, Nodes *node, Elements *elem, Datasets *lcase, int elem_type, double PINF, double TINF, double R_GAS )
+int calcAddEntitiesIsaac( Summen *anz, Nodes *node, Elements *elem, Datasets *lcase, int elem_type, double PINF, double TINF, double R_GAS, double kappa, double cpg )
 {
   int lc, n, i, j, ncomps;
 
-  double p0, t0, rho, ma, mau, mav, maw, rhoE, pcalc, ps, pt, ts, tt, a, vu, vv, vw, v, cpg;
+  double p0, t0, rho, ma, mau, mav, maw, rhoE, pcalc, ps, pt, ts, tt, a, vu, vv, vw, v;
   double rho0, rhocalc;
 
   p0=PINF;
   t0=TINF;
   rho0=p0/R_GAS/t0;
-
-  cpg=R_GAS/(1.-(1./kappa));
+  
+  printf(" calculate additional entities based on: TINF:%f PINF:%f R_GAS:%f GAMMA:%f\n",TINF,PINF,R_GAS,kappa );
 
   for (lc=0; lc<anz->l; lc++)
   {
@@ -151,7 +152,7 @@ C
           v=sqrt(vu*vu+vv*vv+vw*vw);
           pcalc= (kappa-1.)*( rhoE -0.5* rhocalc* v*v );
 
-          /* in ISAAC : (1./kappa)==PREF;  1.=RHOINF; ps=pcalc; */
+          /* in ISAAC : (1./kappa)==PREF; 1.=RHOINF; pps=pcalc; */
           ts=pcalc/R_GAS/rhocalc;
           a=sqrt(kappa*R_GAS*ts);
           mau=vu/a;
@@ -204,17 +205,20 @@ C
 }
 
 
-int readIsaac(char *datin, Summen *anz, Nodes **nptr, Elements **eptr, Datasets **lptr, NodeBlocks **bptr, int elem_type, double PINF, double TINF, double R_GAS )
+int readIsaac(char *datin, Summen *anz, Nodes **nptr, Elements **eptr, Datasets **lptr, NodeBlocks **bptr, int elem_type )
 {
   FILE *handle1=NULL, *handle2=NULL, *handle3=NULL, *handle4=NULL;
-  int i, j, k, n, ld100, lfile;
+  int i, j, k, n, ld100, lfile, print;
   char meshfile[MAX_LINE_LENGTH];
+  char rec_str[MAX_LINE_LENGTH];
   char buffer[MAX_LINE_LENGTH];
+  char dat[3][MAX_LINE_LENGTH];
   int  anz_n;
   int  e_nmax=1, e_nmin=1;
   int  length;
   double fval[1];
-
+  double MACH=0., PINF=0., TINF=0., R_GAS=_R_GAS, GAMMA=1.4, LREF=1., RE=1e6, PR=0.7, VU=0.,VV=0.,VW=0.;
+  double vel,wl,dynVisc,cpGas;
   
   char identifier[MAXIDENTIFIER][MAX_LINE_LENGTH];
   int mnx[MAX_BLOCKS],mny[MAX_BLOCKS],mnz[MAX_BLOCKS];
@@ -228,6 +232,7 @@ int readIsaac(char *datin, Summen *anz, Nodes **nptr, Elements **eptr, Datasets
 
   double fsmach, alpha, Re, time;
 
+  R_GAS=_R_GAS;
 
   if ( (lcase = (Datasets *)malloc( 1 * sizeof(Datasets))) == NULL )
     printf("\n\n ERROR: malloc failed, lcase\n\n") ;
@@ -408,7 +413,8 @@ int readIsaac(char *datin, Summen *anz, Nodes **nptr, Elements **eptr, Datasets
             elem[anz->e].group= i;
             elem[anz->e].mat = 1;
             anz->etype[elem[anz->e].type]++;
-            elem[anz->e].nr  = ++anz->e;
+            anz->e++;
+            elem[anz->e-1].nr  = anz->e;
           }
         }
       }
@@ -442,7 +448,8 @@ int readIsaac(char *datin, Summen *anz, Nodes **nptr, Elements **eptr, Datasets
           elem[anz->e].group= i;
           elem[anz->e].mat = 1;
           anz->etype[elem[anz->e].type]++;
-          elem[anz->e].nr  = ++anz->e;
+          anz->e++;
+          elem[anz->e-1].nr  = anz->e;
         }
       }
     }
@@ -644,7 +651,7 @@ int readIsaac(char *datin, Summen *anz, Nodes **nptr, Elements **eptr, Datasets
     fclose (handle4);
   }
 
-  /* read the basic resuts  */
+  /* read the basic results  */
   if(handle2!=NULL)
   {
     length= fscanf(handle2,"%d",&nblock);
@@ -781,9 +788,61 @@ int readIsaac(char *datin, Summen *anz, Nodes **nptr, Elements **eptr, Datasets
     fclose (handle2);
   }
 
+  /* ------------------------------------------------------------------------- */
+  /* read the input file                                                       */
+  /* ------------------------------------------------------------------------- */
+  printf ("\n Read the input file \n");
+
+  /* input */
+  sprintf(&datin[lfile], ".dat");
+  handle2 = fopen (datin, "r");
+  if ( handle2== NULL )
+  {
+    printf ("\nThe input file \"%s\" could not be opened.\n", datin);
+  }
+  else printf ("\n%s opened\n",datin);
+
+  do
+  {
+    length = frecord( handle2, rec_str);
+    if (rec_str[length] == (char)EOF) break;
+    dat[2][0]=0;
+    length= sscanf(rec_str,"%s %s %s",dat[0], dat[1], dat[2]);
+    print=1;
+    if (compareStrings(dat[0],"'MACH'")>0) MACH=atof(dat[1]);
+    else if (compareStrings(dat[0],"'U'")>0) VU=atof(dat[1]);
+    else if (compareStrings(dat[0],"'V'")>0) VV=atof(dat[1]);
+    else if (compareStrings(dat[0],"'W'")>0) VW=atof(dat[1]);
+    else if (compareStrings(dat[0],"'RE'")>0) RE=atof(dat[1]);
+    else if (compareStrings(dat[0],"'PR'")>0) PR=atof(dat[1]);
+    else if (compareStrings(dat[0],"'TINF'")>0) TINF=atof(dat[1]);
+    else if (compareStrings(dat[0],"'GAMMA'")>0) GAMMA=atof(dat[1]);
+    else if (compareStrings(dat[0],"'REFERENCE")>0) LREF=atof(dat[2]);
+    else print=0;
+    if(print)  printf ("%s %s %s\n",dat[0], dat[1], dat[2] );
+  } while(1);
+  
+  anz->l++;
+  if(VU||VV||VW)
+  {
+    printf("found jet conditions, used now for PINF calculation\n");
+    vel=sqrt(VU*VU+VV*VV+VW*VW)*sqrt(GAMMA*R_GAS*TINF);
+  }
+  else vel=MACH*sqrt(GAMMA*R_GAS*TINF);
+  cpGas=R_GAS/(1.-(1./GAMMA));
+  wl=0.0245*(1.+0.00225*(TINF-273.15));
+  dynVisc=PR/cpGas*wl;
+  PINF=RE*(R_GAS*TINF*dynVisc)/(LREF*vel);
+  printf("v:%f cp:%f wl:%f dynVisc:%f PINF:%f\n",vel,cpGas,wl,dynVisc,PINF);
+
+  /* calculate additional entities */
+  calcAddEntitiesIsaac( anz, node, elem, lcase, elem_type, PINF, TINF, R_GAS, GAMMA, cpGas);
+
+  /* set .loaded to 1 to indicate that the data are available */
+  for (i=0; i<anz->l; i++) { lcase[i].loaded=1; lcase[i].fileptr=NULL; }
+
  endMark:;
 
-  anz->l++;
 
   if ( e_nmax > (anz->nmax) )
   {
@@ -796,12 +855,6 @@ int readIsaac(char *datin, Summen *anz, Nodes **nptr, Elements **eptr, Datasets
     printf (" e_nmax=%d e_nmin=%d \n", e_nmax, e_nmin );
   }
 
-  /* calculate additional entities */
-  calcAddEntitiesIsaac( anz, node, elem, lcase, elem_type, PINF, TINF, R_GAS);
-
-  /* set .loaded to 1 to indicate that the data are available */
-  for (i=0; i<anz->l; i++) { lcase[i].loaded=1; lcase[i].fileptr=NULL; }
-
   *nptr =  node; *eptr = elem; *lptr = lcase; *bptr = block;
   strcpy(datin, meshfile);
   return (1);
