@@ -33,7 +33,7 @@
 
 void freeDataset(Datasets *lcase, int nr)
 {
-  register int i;
+  int i;
 
   printf(" free lc[%d] ncomps:%d\n",nr,lcase[nr].ncomps);
   if(lcase[nr].loaded)
@@ -159,7 +159,8 @@ int readfrd( char *datin, Summen *anz, Nodes **nptr, Elements **eptr, Datasets *
 
 
     flag = stoi(rec_str,1,5);
-    format_flag = stoi(rec_str,74,75);
+    if(strlen(rec_str)>73) format_flag = stoi(rec_str,74,75);
+    else format_flag = 0;
     //printf ("OPCODE:%d IFORMT:%d\n", flag, format_flag );
 
     if(flag == 9999) goto read_again;
@@ -571,6 +572,7 @@ int readfrd( char *datin, Summen *anz, Nodes **nptr, Elements **eptr, Datasets *
         printf("nods in block assumed:%d\n",nod_data );
       }
 #endif
+      lcase[anz->l].numnod=nod_data;
       stos( rec_str, 37, 56, lcase[anz->l].dataset_text);
       lcase[anz->l].analysis_type=stoi( rec_str, 57, 58 );
       lcase[anz->l].step_number=stoi( rec_str, 59, 63 );
@@ -1397,10 +1399,10 @@ int readfrd( char *datin, Summen *anz, Nodes **nptr, Elements **eptr, Datasets *
 
 /* if a block was skipped during first read of frd-file read it now */
 /* return -1 if failure */
-int readfrdblock(int lc, Summen *anz,   Nodes     *node, Datasets *lcase )
+int readfrdblock(int lc, Summen *anz,   Nodes     *node,Datasets *lcase )
 {
-  register int i,j, n;
-  int  length, flag, format_flag, nodenr=0, ncomps;
+  int i,j, n;
+  int  length, flag, format_flag, nodenr=0, ncomps, nvals;
   int  nod_data=0, maxcomps=0;
   int  errFlag=0;
   char rec_str[MAX_LINE_LENGTH];
@@ -1471,15 +1473,18 @@ int readfrdblock(int lc, Summen *anz,   Nodes     *node, Datasets *lcase )
         {
           if ( (value = (float *)realloc((float *)value, (lcase[lc].ncomps) * sizeof(float))) == NULL )
             printf("\n\n ERROR: realloc failed, value\n\n") ;
+          nvals=0;
+          for (i=0; i<lcase[lc].ncomps; i++) if(lcase[lc].iexist[i]!=1) nvals++;
           for(n=0; n<nod_data; n++)
           {
             length=fread((int *)&nodenr,sizeof(int),1,handle);
-            length=fread((float *)value,sizeof(float),lcase[lc].ncomps,handle);
+            length=fread((float *)value,sizeof(float),nvals,handle);
   	  // printf("N:%d ",nodenr);
             for(i=0; i<lcase[lc].ncomps; i++)
             {
   	    // printf(" %f",value[i]); 
-              lcase[lc].dat[i][nodenr]= value[i];
+              if(lcase[lc].iexist[i]!=1) lcase[lc].dat[i][nodenr]= value[i];
+	      else lcase[lc].dat[i][nodenr]=0.;
             }
   	  // printf("\n");
           }
@@ -1488,15 +1493,18 @@ int readfrdblock(int lc, Summen *anz,   Nodes     *node, Datasets *lcase )
         {
           if ( (dvalue = (double *)realloc((double *)dvalue, (lcase[lc].ncomps) * sizeof(double))) == NULL )
             printf("\n\n ERROR: realloc failed, dvalue\n\n") ;
+          nvals=0;
+          for (i=0; i<lcase[lc].ncomps; i++) if(lcase[lc].iexist[i]!=1) nvals++;
           for(n=0; n<nod_data; n++)
           {
             length=fread((int *)&nodenr,sizeof(int),1,handle);
-            length=fread((double *)dvalue,sizeof(double),lcase[lc].ncomps,handle);
+            length=fread((double *)dvalue,sizeof(double),nvals,handle);
   	  // printf("N:%d ",nodenr);
             for(i=0; i<lcase[lc].ncomps; i++)
             {
   	    // printf(" %f",dvalue[i]); 
-              lcase[lc].dat[i][nodenr]= dvalue[i];
+              if(lcase[lc].iexist[i]!=1) lcase[lc].dat[i][nodenr]= dvalue[i];
+	      else lcase[lc].dat[i][nodenr]=0.;
             }
   	  // printf("\n");
           }
@@ -1659,23 +1667,25 @@ int readOneNode( int lc, Summen *anz, Datasets *lcase, int nodenr, double **vptr
   {
     if ( (value = (float *)realloc((float *)value, (lcase[lc].ncomps) * sizeof(float))) == NULL )
       printf("\n\n ERROR: realloc failed, value\n\n") ;
+    nvals=n=0;
+    for (i=0; i<lcase[lc].ncomps; i++) if(lcase[lc].iexist[i]!=1) nvals++;
     do
     {
       length=fread((int *)&inodenr,sizeof(int),1,handle)*sizeof(int);
-      length+=fread((float *)value,sizeof(float),lcase[lc].ncomps,handle)*sizeof(float);
+      length+=fread((float *)value,sizeof(float),nvals,handle)*sizeof(float);
       //printf("N:%d ",inodenr);
-      //for(i=0; i<lcase[lc].ncomps; i++) printf(" %f",value[i]);
+      //for(i=0; i<nvals; i++) printf(" %f",value[i]);
       //printf("\n");
       if(inodenr==nodenr) break;
       else offset+=length;
-    }while(1);
-    for(i=0; i<lcase[lc].ncomps; i++)
+    }while(++n<lcase[lc].numnod);
+    for(i=0; i<nvals; i++)
     {
 	//printf(" %f",value[i]);
       dat[i]= value[i];
     }
 
-    *byte_offset=offset;
+    //*byte_offset=offset;
     //printf("offset:%d\n", offset);
     return(0);
   }
@@ -1683,23 +1693,25 @@ int readOneNode( int lc, Summen *anz, Datasets *lcase, int nodenr, double **vptr
   {
     if ( (dvalue = (double *)realloc((double *)dvalue, (lcase[lc].ncomps) * sizeof(double))) == NULL )
       printf("\n\n ERROR: realloc failed, dvalue\n\n") ;
+    nvals=n=0;
+    for (i=0; i<lcase[lc].ncomps; i++) if(lcase[lc].iexist[i]!=1) nvals++;
     do
     {
       length=fread((int *)&inodenr,sizeof(int),1,handle)*sizeof(int);
-      length+=fread((double *)dvalue,sizeof(double),lcase[lc].ncomps,handle)*sizeof(double);
+      length+=fread((double *)dvalue,sizeof(double),nvals,handle)*sizeof(double);
       //printf("N:%d ",inodenr);
-      //for(i=0; i<lcase[lc].ncomps; i++) printf(" %f",dvalue[i]);
+      //for(i=0; i<nvals; i++) printf(" %f",dvalue[i]);
       //printf("\n");
       if(inodenr==nodenr) break;
       else offset+=length;
-    }while(1);
-    for(i=0; i<lcase[lc].ncomps; i++)
+    }while(++n<lcase[lc].numnod);
+    for(i=0; i<nvals; i++)
     {
 	//printf(" %f",dvalue[i]);
       dat[i]= dvalue[i];
     }
 
-    *byte_offset=offset;
+    //*byte_offset=offset;
     //printf("offset:%d\n", offset);
     return(0);
   }
