@@ -8,11 +8,13 @@ double v_norm( double *A, double *C )
   double    B;
 
   B = sqrt(A[0]*A[0]+A[1]*A[1]+A[2]*A[2]);
-  
-  C[0]=A[0]/B;
-  C[1]=A[1]/B;
-  C[2]=A[2]/B;
-  
+  if(B==0.) C[0]=C[1]=C[2]=0.;
+  else
+  {
+    C[0]=A[0]/B;
+    C[1]=A[1]/B;
+    C[2]=A[2]/B;
+  }
   return(B);
 }
 
