@@ -386,8 +386,7 @@ int write2aba( char *datout, Summen *anz, Nodes *node, Elements *elem, Datasets
   
         for (i=0; i<anz->n; i++)
         {
-          fprintf (handle2, "%8d, %12.5f\n", node[i].nr,
-          lcase[lc].dat[0][node[i].nr]);
+          fprintf (handle2, "%8d, %.7e\n", node[i].nr, lcase[lc].dat[0][node[i].nr]);
         }
         
         if( (compare( dat[0], "tmf", 3)== 3) || (compare( dat[0], "sta", 3)== 3) )
@@ -425,7 +424,7 @@ int write2aba( char *datout, Summen *anz, Nodes *node, Elements *elem, Datasets
             fprintf (handle2, "** %s %s\n", lcase[lc].name,lcase[lc].compName[n] );
             for (i=0; i<anz->n; i++)
             {
-              fprintf (handle2, "%8d, %f\n", node[i].nr, lcase[lc].dat[n][node[i].nr]);
+              fprintf (handle2, "%8d, %.7e\n", node[i].nr, lcase[lc].dat[n][node[i].nr]);
             }
           }
           else
@@ -436,8 +435,8 @@ int write2aba( char *datout, Summen *anz, Nodes *node, Elements *elem, Datasets
             fprintf (handle2, "** %s %s\n", lcase[lc].name,lcase[lc].compName[n] );
             for (i=0; i<anz->n; i++)
             {
-	      if(lcase[lc].ncomps==1) fprintf (handle2, "%8d, %f\n", node[i].nr, lcase[lc].dat[n][node[i].nr]);
-              else fprintf (handle2, "%8d,%d,%f\n", node[i].nr, n+1, lcase[lc].dat[n][node[i].nr]);
+	      if(lcase[lc].ncomps==1) fprintf (handle2, "%8d, %.7e\n", node[i].nr, lcase[lc].dat[n][node[i].nr]);
+              else fprintf (handle2, "%8d,%d,%.7e\n", node[i].nr, n+1, lcase[lc].dat[n][node[i].nr]);
             }
            }
           }
