@@ -23,6 +23,37 @@
 #include <cgx.h>
 
 #define MAX_GSUR_PARAMERTER 8
+extern Scale     scale[1];
+extern Elements  *e_enqire;     /* elem-array by elem-number instead of elem[index]... */
+extern Summen    anz[1];
+extern Edges     *edge;
+extern Nodes     *node;
+extern Datasets *lcase;
+extern Faces     *face;
+extern NodeBlocks *nBlock;
+extern BGpicture *bgpicture;
+
+extern Meshp meshp;
+
+extern Alias     *alias;
+extern Sets      *set;
+extern Shapes    *shape;
+extern Materials *material; 
+extern Psets     *pset;
+extern Values    *value;
+extern Points    *point;
+extern Lines     *line;
+extern Lcmb      *lcmb;
+extern Gsur      *surf;
+extern Gbod      *body;
+extern Nurbl     *nurbl;
+extern Nurbs     *nurbs;
+extern Materials *material; 
+extern Amplitudes *amplitude; 
+extern SumGeo    anzGeo[1];
+extern SumAsci   sumAsci[1];
+extern Texts     *ntext;
+
 extern SpecialSet specialset[1];
 extern Eqal eqal;
 extern int entitycols;
@@ -40,21 +71,26 @@ extern Scale scale[1];
 extern int backgrndcol,legend_font,draw_font,menu_font;
 extern char modelEdgeFlag,elemEdgeFlag,surfFlag,illumResultFlag;
 extern char  inpformat;       /* defines the start-up mode of cgx */
+extern int   cur_entity;                                       /* aktive entity (component), entity in menu= cur_entity+1*/
+extern int   entity_v[6];                                         /* components of a vector-entity */
+extern double v_factor;                                    /* scaling-factor for the vectors in the vector-plot */
+extern double v_scale;                                     /* additional scaling-factor for the vectors */
+extern int       pre_lc;                                      /* pre-selected Dataset, active after entity is selected */
+extern int       cur_lc;                                          /* aktive Dataset */
+extern char  drawMode;               /* protokoliert drawFunktion (Load=1,Light=2,Animate=3,preprocessor=4, vector=5)*/
+extern int   steps;                                  /* Schrittweite der Farbscala */
 
 
-int writefbd(char *setname, Summen *anz, SumGeo *anzGeo, Points *pnt, Lines *line, Lcmb *lcmb, Gsur *surf, Gbod *body, Nurbs *nurbs, Sets *set, Shapes *shape, Values *value, char *format )
+int writefbd(char *setname, char *format )
 {
   FILE *handle1;
   int  i, j, k, n, l, se, nr;
   char string[MAX_LINE_LENGTH], datout[MAX_LINE_LENGTH], buffer[MAX_LINE_LENGTH];
-  int length, params, setNr, nsave;
+  int length, params, setNr, setBuf, nsave;
   int bias_fbd;
   double p1[3], p2[3];
-  /*
-  char attr;
-  char elty[MAX_LINE_LENGTH];
-  char **elty_string=NULL;
-  */
+  Points *pnt;
+  pnt=point;
 
   setNr=getSetNr(setname);
   if (setNr<0)
@@ -74,27 +110,46 @@ int writefbd(char *setname, Summen *anz, SumGeo *anzGeo, Points *pnt, Lines *lin
   handle1 = fopen (datout, "w+b");
   if (handle1==NULL) { printf ("\nThe output file \"%s\" could not be opened.\n\n", datout); return(-1);}
   else  printf ("\n%s opened\n",datout);
-
+  fprintf (handle1,"# written by cgx_%s\n", VERSION);
   printf ("\n write fbd  \n");
   delSet(specialset->tmp);
 
+  if( (setBuf=pre_seta("-setbuf", "i", 0)) <0) return(-1);
+  for (j=0; j<set[setNr].anz_v; j++) seta( setBuf, "v", set[setNr].valu[j] );
+  for (j=0; j<set[setNr].anz_n; j++) seta( setBuf, "n", set[setNr].node[j] );
+  for (j=0; j<set[setNr].anz_e; j++) seta( setBuf, "e", set[setNr].elem[j] );
+  for (j=0; j<set[setNr].anz_f; j++) seta( setBuf, "f", set[setNr].face[j] );
+  for (j=0; j<set[setNr].anz_p; j++) seta( setBuf, "p", set[setNr].pnt[j] );
+  for (j=0; j<set[setNr].anz_l; j++) seta( setBuf, "l", set[setNr].line[j] );
+  for (j=0; j<set[setNr].anz_c; j++) seta( setBuf, "c", set[setNr].lcmb[j] );
+  for (j=0; j<set[setNr].anz_s; j++) seta( setBuf, "s", set[setNr].surf[j] );
+  for (j=0; j<set[setNr].anz_b; j++) seta( setBuf, "b", set[setNr].body[j] );
+  for (j=0; j<set[setNr].anz_nurl; j++) seta( setBuf, "L", set[setNr].nurl[j] );
+  for (j=0; j<set[setNr].anz_nurs; j++) seta( setBuf, "S", set[setNr].nurs[j] );
+  for (j=0; j<set[setNr].anz_sh; j++) seta( setBuf, "sh", set[setNr].shp[j] );
+  for (j=0; j<set[setNr].anz_se; j++) seta( setBuf, "r", set[setNr].set[j] );
+  setNr=setBuf;
+
   /* do not save entities stored in set :NOSAVE */
   /* remove the contents of nsave from setNr */
   nsave=getSetNr(specialset->nsave);
-  for (j=0; j<set[nsave].anz_v; j++) setr( setNr, "v", set[nsave].valu[j] );
-  for (j=0; j<set[nsave].anz_n; j++) setr( setNr, "n", set[nsave].node[j] );
-  for (j=0; j<set[nsave].anz_e; j++) setr( setNr, "e", set[nsave].elem[j] );
-  for (j=0; j<set[nsave].anz_f; j++) setr( setNr, "f", set[nsave].face[j] );
-  for (j=0; j<set[nsave].anz_p; j++) setr( setNr, "p", set[nsave].pnt[j] );
-  for (j=0; j<set[nsave].anz_l; j++) setr( setNr, "l", set[nsave].line[j] );
-  for (j=0; j<set[nsave].anz_c; j++) setr( setNr, "c", set[nsave].lcmb[j] );
-  for (j=0; j<set[nsave].anz_s; j++) setr( setNr, "s", set[nsave].surf[j] );
-  for (j=0; j<set[nsave].anz_b; j++) setr( setNr, "b", set[nsave].body[j] );
-  for (j=0; j<set[nsave].anz_nurl; j++) setr( setNr, "L", set[nsave].nurl[j] );
-  for (j=0; j<set[nsave].anz_nurs; j++) setr( setNr, "S", set[nsave].nurs[j] );
-  for (j=0; j<set[nsave].anz_sh; j++) setr( setNr, "sh", set[nsave].shp[j] );
-  for (j=0; j<set[nsave].anz_se; j++) setr( setNr, "r", set[nsave].set[j] );
-
+  if(nsave>0)
+  {
+    for (j=0; j<set[nsave].anz_v; j++) setr( setNr, "v", set[nsave].valu[j] );
+    for (j=0; j<set[nsave].anz_n; j++) setr( setNr, "n", set[nsave].node[j] );
+    for (j=0; j<set[nsave].anz_e; j++) setr( setNr, "e", set[nsave].elem[j] );
+    for (j=0; j<set[nsave].anz_f; j++) setr( setNr, "f", set[nsave].face[j] );
+    for (j=0; j<set[nsave].anz_p; j++) setr( setNr, "p", set[nsave].pnt[j] );
+    for (j=0; j<set[nsave].anz_l; j++) setr( setNr, "l", set[nsave].line[j] );
+    for (j=0; j<set[nsave].anz_c; j++) setr( setNr, "c", set[nsave].lcmb[j] );
+    for (j=0; j<set[nsave].anz_s; j++) setr( setNr, "s", set[nsave].surf[j] );
+    for (j=0; j<set[nsave].anz_b; j++) setr( setNr, "b", set[nsave].body[j] );
+    for (j=0; j<set[nsave].anz_nurl; j++) setr( setNr, "L", set[nsave].nurl[j] );
+    for (j=0; j<set[nsave].anz_nurs; j++) setr( setNr, "S", set[nsave].nurs[j] );
+    for (j=0; j<set[nsave].anz_sh; j++) setr( setNr, "sh", set[nsave].shp[j] );
+    for (j=0; j<set[nsave].anz_se; j++) setr( setNr, "r", set[nsave].set[j] );
+  }
+  
   if (anzGeo->p)
   {
       for (i=0; i<set[setNr].anz_p; i++)
@@ -205,7 +260,7 @@ int writefbd(char *setname, Summen *anz, SumGeo *anzGeo, Points *pnt, Lines *lin
   {
     if( compare( setname, "all", 3)==3)
     {
-      for (i=0; i<anzGeo->l; i++)
+      for (i=0; i<anzGeo->l; i++) if( line[i].name != (char *)NULL )
       {
         /* load bias and division in buffer */
         if(line[i].div<100)
@@ -262,7 +317,7 @@ int writefbd(char *setname, Summen *anz, SumGeo *anzGeo, Points *pnt, Lines *lin
         {
           if(line[i].etyp>0)
 	  {
-            fprintf (handle1, " MSHP %s l %d %d\n", line[i].name, line[i].etyp, line[i].eattr );
+            fprintf (handle1, " MSHP %s l %d %d %d\n", line[i].name, line[i].etyp, line[i].eattr, line[i].elock );
 	  }
         }
       }
@@ -326,7 +381,7 @@ int writefbd(char *setname, Summen *anz, SumGeo *anzGeo, Points *pnt, Lines *lin
         {
           if(line[j].etyp>0)
 	  {
-            fprintf (handle1, " MSHP %s l %d %d\n", line[j].name, line[j].etyp, line[j].eattr );
+            fprintf (handle1, " MSHP %s l %d %d %d\n", line[j].name, line[j].etyp, line[j].eattr, line[j].elock );
 	  }
         }
       }
@@ -520,6 +575,7 @@ int writefbd(char *setname, Summen *anz, SumGeo *anzGeo, Points *pnt, Lines *lin
       {
         if( surf[i].name != (char *)NULL )
         {
+	  if(!surf[i].o[0]) { surf[i].o[0]='+'; k=1; } else k=0;
           if(surf[i].sh>-1) fprintf (handle1, " GSUR %s %1c %s", surf[i].name, surf[i].ori, shape[surf[i].sh].name );
           else fprintf (handle1, " GSUR %s %1c BLEND", surf[i].name, surf[i].ori );
           params=0; 
@@ -538,6 +594,7 @@ int writefbd(char *setname, Summen *anz, SumGeo *anzGeo, Points *pnt, Lines *lin
             }
           }
           fprintf (handle1, " \n");
+          if(k) { surf[i].o[0]=0; }
         }
       }
       for (i=0; i<anzGeo->s; i++)
@@ -547,9 +604,9 @@ int writefbd(char *setname, Summen *anz, SumGeo *anzGeo, Points *pnt, Lines *lin
           if(surf[i].etyp>0)
 	  {
             if( surf[i].eparm != (char *)NULL )
-              fprintf (handle1, " MSHP %s s %d %d %s\n", surf[i].name, surf[i].etyp, surf[i].eattr, surf[i].eparm );
+              fprintf (handle1, " MSHP %s s %d %d %d %s\n", surf[i].name, surf[i].etyp, surf[i].eattr, surf[i].elock, surf[i].eparm );
             else
-              fprintf (handle1, " MSHP %s s %d %d\n", surf[i].name, surf[i].etyp, surf[i].eattr );
+              fprintf (handle1, " MSHP %s s %d %d %d\n", surf[i].name, surf[i].etyp, surf[i].eattr, surf[i].elock );
 	  }
         }
       }
@@ -558,25 +615,27 @@ int writefbd(char *setname, Summen *anz, SumGeo *anzGeo, Points *pnt, Lines *lin
     {
       for (i=0; i<set[setNr].anz_s; i++)
       {
-          n=set[setNr].surf[i];
-          if(surf[n].sh<=-1) fprintf (handle1, " GSUR %s %1c BLEND", surf[n].name, surf[n].ori );
-          else if(surf[n].sh>-1) fprintf (handle1, " GSUR %s %1c %s", surf[n].name, surf[n].ori, shape[surf[n].sh].name );
-          params=0; 
-          for (j=0; j<surf[n].nl; j++)
+        n=set[setNr].surf[i];
+	if(!surf[n].o[0]) { surf[n].o[0]='+'; k=1; } else k=0;
+        if(surf[n].sh<=-1) fprintf (handle1, " GSUR %s %1c BLEND", surf[n].name, surf[n].ori );
+        else if(surf[n].sh>-1) fprintf (handle1, " GSUR %s %1c %s", surf[n].name, surf[n].ori, shape[surf[n].sh].name );
+        params=0; 
+        for (j=0; j<surf[n].nl; j++)
+        {
+          if (params==MAX_GSUR_PARAMERTER)
+          { params=0; fprintf (handle1, "\n GSUR %s ADD", surf[n].name); }
+          else  params++; 
+          if (surf[n].typ[j]=='l')
           {
-            if (params==MAX_GSUR_PARAMERTER)
-            { params=0; fprintf (handle1, "\n GSUR %s ADD", surf[n].name); }
-            else  params++; 
-            if (surf[n].typ[j]=='l')
-            {
-              fprintf (handle1, " %1c %s", surf[n].o[j], line[surf[n].l[j]].name );
-            }
-            else
-            {
-              fprintf (handle1, " %1c %s", surf[n].o[j], lcmb[surf[n].l[j]].name );
-            }
+            fprintf (handle1, " %1c %s", surf[n].o[j], line[surf[n].l[j]].name );
+          }
+          else
+          {
+            fprintf (handle1, " %1c %s", surf[n].o[j], lcmb[surf[n].l[j]].name );
+          }
         }
         fprintf (handle1, " \n");
+        if(k) { surf[n].o[0]=0; }
       }
       for (n=0; n<set[setNr].anz_s; n++)
       {
@@ -586,9 +645,9 @@ int writefbd(char *setname, Summen *anz, SumGeo *anzGeo, Points *pnt, Lines *lin
           if(surf[i].etyp>0)
 	  {
             if( surf[i].eparm != (char *)NULL )
-              fprintf (handle1, " MSHP %s s %d %d %s\n", surf[i].name, surf[i].etyp, surf[i].eattr, surf[i].eparm );
+              fprintf (handle1, " MSHP %s s %d %d %d %s\n", surf[i].name, surf[i].etyp, surf[i].eattr, surf[i].elock, surf[i].eparm );
             else
-              fprintf (handle1, " MSHP %s s %d %d\n", surf[i].name, surf[i].etyp, surf[i].eattr );
+              fprintf (handle1, " MSHP %s s %d %d %d\n", surf[i].name, surf[i].etyp, surf[i].eattr, surf[i].elock );
           }
         }
       }
@@ -622,9 +681,9 @@ int writefbd(char *setname, Summen *anz, SumGeo *anzGeo, Points *pnt, Lines *lin
           if(body[i].etyp>0)
 	  {
             if( body[i].eparm != (char *)NULL )
-              fprintf (handle1, " MSHP %s b %d %d %s\n", body[i].name, body[i].etyp, body[i].eattr, body[i].eparm );
+              fprintf (handle1, " MSHP %s b %d %d %d %s\n", body[i].name, body[i].etyp, body[i].eattr, body[i].elock, body[i].eparm );
             else
-              fprintf (handle1, " MSHP %s b %d %d\n", body[i].name, body[i].etyp, body[i].eattr );
+              fprintf (handle1, " MSHP %s b %d %d %d\n", body[i].name, body[i].etyp, body[i].eattr, body[i].elock );
 	  }
         }
       }
@@ -656,9 +715,9 @@ int writefbd(char *setname, Summen *anz, SumGeo *anzGeo, Points *pnt, Lines *lin
           if(body[i].etyp>0)
 	  {
             if( body[i].eparm != (char *)NULL )
-              fprintf (handle1, " MSHP %s b %d %d %s\n", body[i].name, body[i].etyp, body[i].eattr, body[i].eparm );
+              fprintf (handle1, " MSHP %s b %d %d %d %s\n", body[i].name, body[i].etyp, body[i].eattr, body[i].elock, body[i].eparm );
             else
-              fprintf (handle1, " MSHP %s b %d %d\n", body[i].name, body[i].etyp, body[i].eattr );
+              fprintf (handle1, " MSHP %s b %d %d %d\n", body[i].name, body[i].etyp, body[i].eattr, body[i].elock );
 	  }
         }
       }
@@ -692,6 +751,25 @@ int writefbd(char *setname, Summen *anz, SumGeo *anzGeo, Points *pnt, Lines *lin
   {
     if((!set[i].type)&&( set[i].name!=(char *)NULL)&&( set[i].name[0]!='_')&&( set[i].name[0]!='-')) /* ordinary SET */
     {
+      if( compare( setname, "all", 3)==3);
+      else
+      {
+      k=0; for (j=0; j<set[i].anz_n; j++) if( getIndex(&set[setNr].node,set[setNr].anz_n,set[i].node[j]) >-1)
+      {
+        if(k==0) { fprintf (handle1, " SETA %s n", set[i].name); }
+        fprintf (handle1, " %d", set[i].node[j]);  k++;
+        if((k==7)&&(j!=set[i].anz_n-1)) { fprintf (handle1, "\n"); k=0; }
+      }
+      if(k) { fprintf (handle1, "\n"); }
+      k=0; for (j=0; j<set[i].anz_e; j++) if( getIndex(&set[setNr].elem,set[setNr].anz_e,set[i].elem[j]) >-1)
+      {
+        if(k==0) { fprintf (handle1, " SETA %s e", set[i].name); }
+        fprintf (handle1, " %d", set[i].elem[j]);   k++;
+        if((k==7)&&(j!=set[i].anz_e-1)) { fprintf (handle1, "\n"); k=0; }
+      }
+      if(k) { fprintf (handle1, "\n"); }
+      }
+
       /*  FAM vertraegt nur einen wert hinter der spec.  */
       for (j=0; j<set[i].anz_p; j++) if( getIndex(&set[setNr].pnt,set[setNr].anz_p,set[i].pnt[j]) >-1)
       {
@@ -724,21 +802,6 @@ int writefbd(char *setname, Summen *anz, SumGeo *anzGeo, Points *pnt, Lines *lin
     }
   }
 
-  /* restore the contents of setNr */
-  for (j=0; j<set[nsave].anz_v; j++) seta( setNr, "v", set[nsave].valu[j] );
-  for (j=0; j<set[nsave].anz_n; j++) seta( setNr, "n", set[nsave].node[j] );
-  for (j=0; j<set[nsave].anz_e; j++) seta( setNr, "e", set[nsave].elem[j] );
-  for (j=0; j<set[nsave].anz_f; j++) seta( setNr, "f", set[nsave].face[j] );
-  for (j=0; j<set[nsave].anz_p; j++) seta( setNr, "p", set[nsave].pnt[j] );
-  for (j=0; j<set[nsave].anz_l; j++) seta( setNr, "l", set[nsave].line[j] );
-  for (j=0; j<set[nsave].anz_c; j++) seta( setNr, "c", set[nsave].lcmb[j] );
-  for (j=0; j<set[nsave].anz_s; j++) seta( setNr, "s", set[nsave].surf[j] );
-  for (j=0; j<set[nsave].anz_b; j++) seta( setNr, "b", set[nsave].body[j] );
-  for (j=0; j<set[nsave].anz_nurl; j++) seta( setNr, "L", set[nsave].nurl[j] );
-  for (j=0; j<set[nsave].anz_nurs; j++) seta( setNr, "S", set[nsave].nurs[j] );
-  for (j=0; j<set[nsave].anz_sh; j++) seta( setNr, "sh", set[nsave].shp[j] );
-  for (j=0; j<set[nsave].anz_se; j++) seta( setNr, "r", set[nsave].set[j] );
-
   /* write the quality thresholds */
   if(eqal.aspr) fprintf (handle1, " EQAL aspr %lf\n", eqal.aspr);
   if(eqal.jbir) fprintf (handle1, " EQAL jbir %lf\n", eqal.jbir);
@@ -753,7 +816,7 @@ int writefbd(char *setname, Summen *anz, SumGeo *anzGeo, Points *pnt, Lines *lin
 
   if( compare( setname, "all", 3)==3)
   {
-    /* write the user collors */
+    /* write the user colors */
     for(i=SET_COLS; i<entitycols; i++)
     {
       fprintf(handle1, " col %s %f %f %f\n",entitycol[i].name, entitycol[i].r, entitycol[i].g, entitycol[i].b  );
@@ -762,19 +825,41 @@ int writefbd(char *setname, Summen *anz, SumGeo *anzGeo, Points *pnt, Lines *lin
     /* write the nr of threads */
     if(anz->threads>1) fprintf (handle1, " asgn thrds %d\n", anz->threads);
 
-    /* write the initialization commands */
-    if(inpformat) fprintf (handle1, " wpos %d %d\n",glutGet(GLUT_WINDOW_X), glutGet(GLUT_WINDOW_Y));
-    writeInit(handle1);
+    /* define the tetmesher */
+    if(meshp.tetmesher==1) fprintf (handle1, " asgn tetgen\n");
 
+    /* write the initialization commands */
+    //if(inpformat) fprintf (handle1, " wpos %d %d\n",glutGet(GLUT_WINDOW_X), glutGet(GLUT_WINDOW_Y));
+    writeInit(handle1);
+    
     /* write the plot,plus commands */
     for (j=0; j<anzGeo->psets; j++ )
     {
-      if((pset[j].type[0]!='n')&&(pset[j].type[0]!='e')&&(pset[j].type[0]!='f'))
+      //if((pset[j].type[0]!='n')&&(pset[j].type[0]!='e')&&(pset[j].type[0]!='f'))
       {
         if(j==0) fprintf (handle1, " plot %s %s %s\n", pset[j].type, set[pset[j].nr].name, entitycol[pset[j].col].name);
         else fprintf (handle1, " plus %s %s %s\n", pset[j].type, set[pset[j].nr].name, entitycol[pset[j].col].name);
       }
     }
+
+    /* write the current dataset */
+    if((anz->l)&&((drawMode==1)||(drawMode==4)))
+    {
+      fprintf (handle1, " ds %d e %d\n", cur_lc+1, cur_entity+1);
+      fprintf (handle1, " STEPS %d\n", steps);
+      if(scale->smaxr==0) fprintf (handle1, " MAX %lf", scale->smax);
+      if(scale->smaxr==1) fprintf (handle1, " MAXR %lf", scale->smax);
+      if(scale->smaxr==2) fprintf (handle1, " MAXC %lf", scale->smax);
+      if(scale->format) fprintf (handle1, " %c", scale->format);
+      if(scale->lock) fprintf (handle1, " %c", scale->lock);
+      fprintf (handle1, "\n");
+      if(scale->sminr==0) fprintf (handle1, " MIN %lf", scale->smin);
+      if(scale->sminr==1) fprintf (handle1, " MINR %lf", scale->smin);
+      if(scale->sminr==2) fprintf (handle1, " MINC %lf", scale->smin);
+      if(scale->format) fprintf (handle1, " %c", scale->format);
+      if(scale->lock) fprintf (handle1, " %c", scale->lock);
+      fprintf (handle1, "\n");
+    }
   }
   else
   {
@@ -782,6 +867,7 @@ int writefbd(char *setname, Summen *anz, SumGeo *anzGeo, Points *pnt, Lines *lin
     fprintf (handle1, " plus lp %s\n", setname);
   }
   fclose(handle1);
+  delSet("-setbuf");
   return (1);
 }
 
